create table tnt_config.rollup_rules (
	columnName text not null,	
	columnType text not null,
	columnDescription text,
	language text not null,
	ruleExpression text not null,
	countExpression text,
	tableName text not null,
	recordCount boolean not null default false,
	applyTo text not null default 'ALL_DATA',
	primary key (columnName, tableName)
) without oids;
create index rollup_rules_tablename_idx on tnt_config.rollup_rules (tablename);
alter table tnt_config.rollup_rules owner to impadmin;
grant select on table tnt_config.rollup_rules to reports;
-- comments
comment on table tnt_config.rollup_rules is 'contains rules to apply to incoming data for rollup purposes';
comment on column tnt_config.rollup_rules.columnName is 'name of the resulting rolled-up column';
comment on column tnt_config.rollup_rules.columnType is 'column sql type';
comment on column tnt_config.rollup_rules.columnDescription is 'optional column description';
comment on column tnt_config.rollup_rules.language is 'rule language';
comment on column tnt_config.rollup_rules.ruleExpression is 'rule expression';
comment on column tnt_config.rollup_rules.countExpression is 'count expression';
comment on column tnt_config.rollup_rules.tableName is 'column is placed in this table';
comment on column tnt_config.rollup_rules.recordCount is 'record count of items that were included in rule calculation';
comment on column tnt_config.rollup_rules.applyTo is 'what data this rule applies to - ALL_DATA, NEW_DATA_ONLY, OLD_DATA_ONLY';

-- existing rollup columns
INSERT INTO tnt_config.rollup_rules VALUES ('total_app_anr', 'integer', 'sum of all non-responding app counts', 'GROOVY', '(summaryReport.getApplicationStatistics() != null) ? summaryReport.getApplicationStatistics().sum{ it.isNonResponsive() ? 1 : 0 } : 0;', NULL, 'tnt_audit.summaryreports', false, 'NEW_DATA_ONLY');
INSERT INTO tnt_config.rollup_rules VALUES ('total_app_pf', 'integer', 'sum of app average page faults', 'GROOVY', '(summaryReport.getApplicationStatistics() != null) ? summaryReport.getApplicationStatistics().sum{ it.getAveragePageFault() != null ? it.getAveragePageFault() : 0 } : 0;', NULL, 'tnt_audit.summaryreports', false, 'NEW_DATA_ONLY');
INSERT INTO tnt_config.rollup_rules VALUES ('desktop_app_ids', 'integer[]', 'array of desktop app ids seen during interval', 'GROOVY', 'def idList = (summaryReport.getApplicationStatistics() != null) ? summaryReport.getApplicationStatistics().collect{ it.getDesktopApplication() != null ? it.getDesktopApplication().getId() : null }.sort().unique() : null; if (idList != null) { idList.remove(null); }; return idList;', NULL, 'tnt_audit.summaryreports', false, 'NEW_DATA_ONLY');
INSERT INTO tnt_config.rollup_rules VALUES ('login_ids', 'integer[]', 'array of user ids logged in during interval', 'GROOVY', 'def idList = (summaryReport.getLoginStatistics() != null) ? summaryReport.getLoginStatistics().collect{ it.getUser() != null ? it.getUser().getId() : null }.sort().unique() : null; if (idList != null) { idList.remove(null); }; return idList;', NULL, 'tnt_audit.summaryreports', false, 'NEW_DATA_ONLY');
