drop table if exists tnt_config.rollup_rules;
create table tnt_config.rollup_rules (
	columnName text not null,	
	columnType text not null,
	columnDescription text,
	language text not null,
	ruleExpression text not null,
	countExpression text,
	tableName text not null,
	recordCount boolean not null default false,
	applyTo text not null default 'ALL_DATA',
	primary key (columnName, tableName, applyTo),
	applicationTime timestamp,
	tablesAppliedTo text
) without oids;
create index rollup_rules_tablename_idx on tnt_config.rollup_rules (tablename);
alter table tnt_config.rollup_rules owner to impadmin;
grant select on table tnt_config.rollup_rules to reports;
-- comments
comment on table tnt_config.rollup_rules is 'contains rules to apply to incoming data for rollup purposes';
comment on column tnt_config.rollup_rules.columnName is 'name of the resulting rolled-up column';
comment on column tnt_config.rollup_rules.columnType is 'column sql type';
comment on column tnt_config.rollup_rules.columnDescription is 'optional column description';
comment on column tnt_config.rollup_rules.language is 'rule language';
comment on column tnt_config.rollup_rules.ruleExpression is 'rule expression';
comment on column tnt_config.rollup_rules.countExpression is 'count expression';
comment on column tnt_config.rollup_rules.tableName is 'column is placed in this table';
comment on column tnt_config.rollup_rules.recordCount is 'record count of items that were included in rule calculation';
comment on column tnt_config.rollup_rules.applyTo is 'what data this rule applies to - ALL_DATA, NEW_DATA_ONLY, OLD_DATA_ONLY';
comment on column tnt_config.rollup_rules.applicationTime is 'time a rule for old data began applying';
comment on column tnt_config.rollup_rules.tablesAppliedTo is 'for rules that apply to old data only, list of tables applied to.  <= applicationTime';

-- existing rollup columns
INSERT INTO tnt_config.rollup_rules VALUES ('total_app_anr', 'integer', 'sum of all non-responding app counts', 'GROOVY', '(summaryReport.getApplicationStatistics() != null) ? summaryReport.getApplicationStatistics().sum{ it.isNonResponsive() ? 1 : 0 } : 0;', NULL, 'tnt_audit.summaryreports', false, 'NEW_DATA_ONLY', null,  null);
INSERT INTO tnt_config.rollup_rules VALUES ('total_app_pf', 'integer', 'sum of app average page faults', 'GROOVY', '(summaryReport.getApplicationStatistics() != null) ? summaryReport.getApplicationStatistics().sum{ it.getAveragePageFault() != null ? it.getAveragePageFault() : 0 } : 0;', NULL, 'tnt_audit.summaryreports', false, 'NEW_DATA_ONLY', null, null);
INSERT INTO tnt_config.rollup_rules VALUES ('desktop_app_ids', 'integer[]', 'array of desktop app ids seen during interval', 'GROOVY', 'def idList = (summaryReport.getApplicationStatistics() != null) ? summaryReport.getApplicationStatistics().collect{ it.getDesktopApplication() != null ? it.getDesktopApplication().getId() : null } as Set : null; if (idList != null) { idList.remove(null); }; return idList;', NULL, 'tnt_audit.summaryreports', false, 'NEW_DATA_ONLY', null, null);
INSERT INTO tnt_config.rollup_rules VALUES ('login_ids', 'integer[]', 'array of user ids logged in during interval', 'GROOVY', 'def idList = (summaryReport.getLoginStatistics() != null) ? summaryReport.getLoginStatistics().collect{ it.getUser() != null ? it.getUser().getId() : null } as Set : null; if (idList != null) { idList.remove(null); }; return idList;', NULL, 'tnt_audit.summaryreports', false, 'NEW_DATA_ONLY', null, null);
INSERT INTO tnt_config.rollup_rules VALUES ('app_graph_avg', 'double precision', 'average of average process gdi objects', 'GROOVY', 'def sum = 0; def count = 0; if (summaryReport.getApplicationStatistics() != null) { for (appStat in summaryReport.getApplicationStatistics()) { if (appStat.getGraphicsIntensityAverage() != null) { sum += appStat.getGraphicsIntensityAverage(); count++; } } }; return (count > 0) ? sum / count : null;', 'def count = 0; if (summaryReport.getApplicationStatistics() != null) { for (appStat in summaryReport.getApplicationStatistics()) { if (appStat.getGraphicsIntensityAverage() != null) { count++; } } }; return count > 0 ? count : null;', 'tnt_audit.summaryreports', true, 'NEW_DATA_ONLY', null, null);
INSERT INTO tnt_config.rollup_rules VALUES ('app_graph_avg', 'double precision', 'average of average process gdi objects', 'SQL', '
update

tnt_audit.summaryreports sumrpt

set app_graph_avg = iq.avg_graph_avg
from (
	select
	sumrpt.node_id,
	sumrpt.start_date,
	sumrpt.end_date,
	avg(pr_stats.graph_avg) as avg_graph_avg

	from tnt_audit.summaryreports sumrpt

	join tnt_audit.summaryreport_process_stats pr_stats on (
		sumrpt.node_id = pr_stats.node_id and
		sumrpt.start_date = pr_stats.start_date and
		sumrpt.end_date = pr_stats.end_date
	)

	group by sumrpt.node_id, sumrpt.start_date, sumrpt.end_date

	having avg(pr_stats.graph_avg) is not null
) as iq

where sumrpt.app_graph_avg is null and (sumrpt.node_id = iq.node_id and sumrpt.start_date = iq.start_date and sumrpt.end_date = iq.end_date)
', '
update

tnt_audit.summaryreports sumrpt

set app_graph_avg_count = iq.avg_graph_avg_count
from (
        select
        sumrpt.node_id,
        sumrpt.start_date,
        sumrpt.end_date,
        count(pr_stats.*) as avg_graph_avg_count

        from tnt_audit.summaryreports sumrpt

        join tnt_audit.summaryreport_process_stats pr_stats on (
                sumrpt.node_id = pr_stats.node_id and
                sumrpt.start_date = pr_stats.start_date and
                sumrpt.end_date = pr_stats.end_date
		and pr_stats.graph_avg is not null
        )

        group by sumrpt.node_id, sumrpt.start_date, sumrpt.end_date
) as iq

where sumrpt.app_graph_avg is not null and (sumrpt.node_id = iq.node_id and sumrpt.start_date = iq.start_date and sumrpt.end_date = iq.end_date)
', 'tnt_audit.summaryreports', true, 'OLD_DATA_ONLY', null, null);

INSERT INTO tnt_config.rollup_rules VALUES ('app_launch_delay_ms', 'double precision', 'average of app launch delay where delay >= 1s', 'GROOVY', 'def sum = 0; def count = 0; if (summaryReport.getApplicationStatistics() != null) { for (appStat in summaryReport.getApplicationStatistics()) { if (appStat.isFirstRecord() && appStat.getLaunchDelayMs() >= 1000) { sum += appStat.getLaunchDelayMs(); count++; } } }; return (count > 0) ? sum / count : null;', 'def count = 0; if (summaryReport.getApplicationStatistics() != null) { for (appStat in summaryReport.getApplicationStatistics()) { if (appStat.isFirstRecord() && appStat.getLaunchDelayMs() >= 1000) { count++; } } }; return count > 0 ? count : null;', 'tnt_audit.summaryreports', true, 'NEW_DATA_ONLY', null, null);
INSERT INTO tnt_config.rollup_rules VALUES ('app_launch_delay_ms', 'double precision', 'average of app launch delay where delay >= 1s', 'SQL', '
update

tnt_audit.summaryreports sumrpt

set app_launch_delay_ms = iq.avg_app_launch_delay_ms
from (
	select
	sumrpt.node_id,
	sumrpt.start_date,
	sumrpt.end_date,
	avg(pr_stats.launch_delay_ms) as avg_app_launch_delay_ms 

	from tnt_audit.summaryreports sumrpt

	join tnt_audit.summaryreport_process_stats pr_stats on (
		sumrpt.node_id = pr_stats.node_id and
		sumrpt.start_date = pr_stats.start_date and
		sumrpt.end_date = pr_stats.end_date
		and pr_stats.first_record = true 
		and pr_stats.launch_delay_ms >= 1000
	)

	group by sumrpt.node_id, sumrpt.start_date, sumrpt.end_date
) as iq

where sumrpt.app_launch_delay_ms is null and (sumrpt.node_id = iq.node_id and sumrpt.start_date = iq.start_date and sumrpt.end_date = iq.end_date)
', '
update

tnt_audit.summaryreports sumrpt

set app_launch_delay_ms_count = iq.count
from (
        select
        sumrpt.node_id,
        sumrpt.start_date,
        sumrpt.end_date,
        count(pr_stats.*) as count 

        from tnt_audit.summaryreports sumrpt

        join tnt_audit.summaryreport_process_stats pr_stats on (
                sumrpt.node_id = pr_stats.node_id and
                sumrpt.start_date = pr_stats.start_date and
                sumrpt.end_date = pr_stats.end_date
		and pr_stats.first_record = true
		and pr_stats.launch_delay_ms >= 1000
        )

        group by sumrpt.node_id, sumrpt.start_date, sumrpt.end_date
) as iq

where sumrpt.app_launch_delay_ms is not null and (sumrpt.node_id = iq.node_id and sumrpt.start_date = iq.start_date and sumrpt.end_date = iq.end_date)
', 'tnt_audit.summaryreports', true, 'OLD_DATA_ONLY', null, null);
