drop table if exists tnt_config.node_vmhost;
create table tnt_config.node_vmhost (
	node_id int not null references tnt_config.node (id) on delete cascade on update cascade,
	vmhost_id int not null references tnt_config.vmhost (id) on delete cascade on update cascade,
	creation_time timestamp not null default current_timestamp,
	delete_time timestamp
) Without Oids;
create unique index node_vmhost_node_id_idx on tnt_config.node_vmhost (node_id) where (delete_time is null);
alter table tnt_config.node_vmhost owner to impadmin;
grant select on table tnt_config.node_vmhost to reports;
insert into tnt_config.node_vmhost (
	select id, vmhost_id from tnt_config.node where delete_time is null and vmhost_id is not null
);
-- rollback creation_time so any historical queries at least match current entry
update tnt_config.node_vmhost set creation_time = '1970-01-01 00:00:00'::timestamp;
drop view lwl_query.san_performance;
-- to be done later
-- alter table tnt_config.node drop vmhost_id;
create view lwl_query.san_performance as
 SELECT dstore.name AS san_name, dstore.disk_names AS san_location, vmhost.name AS host_name, pn.name AS vm_name, mstats.start_date AS inspect_start_time_utc, mstats.end_date AS inspect_end_time_utc, avg(dstats.read_avg) AS avg_read_iops, avg(dstats.write_avg) AS avg_write_iops, avg(dstats.read_io_avg) AS avg_read_kb_s, avg(dstats.write_io_avg) AS avg_write_kb_s, avg(dstats.queue_avg) AS avg_queue_length, max(dstats.read_peak) AS peak_read_iops, max(dstats.write_peak) AS peak_write_iops, max(dstats.read_io_peak) AS peak_read_kb_s, max(dstats.write_io_peak) AS peak_write_kb_s, max(dstats.queue_peak) AS peak_queue_length
   FROM tnt_audit.summaryreports mstats
   JOIN tnt_config.policynode pn ON mstats.node_id = pn.id
   JOIN tnt_config.node nd ON mstats.node_id = nd.id
   JOIN tnt_config.node_vmhost nd_vmh on nd_vmh.node_id = nd.id and nd_vmh.creation_time >= mstats.end_date and (nd_vmh.delete_time <= mstats.end_date or nd_vmh.delete_time is null)
   JOIN tnt_config.vmhost vmhost ON nd_vmh.vmhost_id = vmhost.id
   JOIN tnt_audit.summaryreport_partition_stats dstats ON mstats.node_id = dstats.node_id AND mstats.start_date = dstats.start_date AND mstats.end_date = dstats.end_date
   JOIN tnt_config.datastore dstore ON dstats.vdisk_datastoreid = dstore.id
  GROUP BY dstore.name, dstore.disk_names, vmhost.name, pn.name, mstats.start_date, mstats.end_date;
