create or replace function "tnt_audit".text_trend_to_array(baseTable text, columnName text)
returns integer as
'
declare
	partitionCount int;
	rowCount int;
	tmpColumnName text;
	partitionInfo record;
begin
	partitionCount := 0;
	tmpColumnName := columnName || ''_ary'';
	raise debug ''Converting column % in table % to array.  New temp column name: % '', columnName, baseTable, tmpColumnName;
	-- make sure existing column doesnt have null constraint
	execute format(''alter table tnt_audit.%I alter column %I drop not null'', baseTable, columnName);
	-- create new column
	execute format(''alter table tnt_audit.%I add %I smallint[]'', baseTable, tmpColumnName);

	return partitionCount;
end;	
'
Language 'plpgsql'
 Volatile
 Called On Null Input
 Security invoker;

create or replace function "tnt_audit".text_trends_to_array(baseTable text)
returns integer as
'
declare
	columnCount int;
	columnInfo record;
begin
	columnCount := 0;
	raise debug ''Converting all text trends on table % to arrays'', baseTable;
	for columnInfo in select column_name from information_schema.columns where table_schema = ''tnt_audit'' and table_name = baseTable and data_type = ''text'' and column_name ~ ''.*trend.*'' LOOP
		raise debug ''Processing column: %'', columnInfo.column_name;
		columnCount := columnCount + 1;
		perform tnt_audit.text_trend_to_array(baseTable, columnInfo.column_name);
	end loop;

	return columnCount;
end;
'
Language 'plpgsql'
 Volatile
 Called On Null Input
 Security invoker;

select tnt_audit.text_trends_to_array('summaryreports');
select tnt_audit.text_trends_to_array('summaryreport_partition_stats');
select tnt_audit.text_trends_to_array('summaryreport_login_stats');
select tnt_audit.text_trends_to_array('summaryreport_process_stats');
select tnt_audit.text_trends_to_array('summaryreport_datastore_stats');
select tnt_audit.text_trends_to_array('summaryreport_nic_stats');
select tnt_audit.text_trends_to_array('summaryreport_folder_stats');
select tnt_audit.text_trends_to_array('summaryreport_folder_ext_stats');
select tnt_audit.text_trends_to_array('summaryreport_ping_stats');
select tnt_audit.text_trends_to_array('summaryreport_gpu_stats');
select tnt_audit.text_trends_to_array('summaryreport_display_proto_stats');

drop function tnt_audit.text_trends_to_array(text);
drop function tnt_audit.text_trend_to_array(text, text);
