drop view lwl_query.user_performance;
drop view lwl_query.machine_performance;
alter table tnt_audit.summaryreport_login_stats alter COLUMN login_delay_ms type real;
create view lwl_query.user_performance as
SELECT log_stats.name AS user_name,
    usergroup.name AS user_group,
    mstats.start_date AS inspect_start_time_utc,
    mstats.end_date AS inspect_end_time_utc,
    avg(mstats.vdi_fit_overall) AS vdi_fit,
    avg(mstats.vdi_ux_overall) AS vdi_ux,
    count(DISTINCT pmachine.name) AS desktops_used,
    avg(log_stats.login_delay_ms) / 1000::numeric AS avg_login_delay_s,
    avg(mstats.cpu_avg_sys) AS avg_system_cpu_percent,
    avg(mstats.cpu_avg_user) AS avg_user_cpu_percent,
    avg(mstats.cpu_queue_avg) AS avg_cpu_queue_len,
    avg(mstats.cpu_cswitch_avg) AS avg_cpu_context_switch_per_s,
    avg(mstats.mem_avg / 1024::double precision) AS avg_mem_used_mb,
    avg((mstats.mem_avg + mstats.swap_avg) / (mstats.mem_alloc + mstats.swap_alloc + 1::double precision) * 100::double precision) AS avg_mem_used_percent,
    avg(disk_stats.avg_used / 1024::double precision) AS avg_disk_used_mb,
    avg(disk_stats.read_avg + disk_stats.write_avg) AS avg_disk_iops,
    avg(disk_stats.read_io_avg + disk_stats.write_io_avg) AS avg_disk_kb_s,
    avg(disk_stats.queue_avg) AS avg_disk_queue_len,
    avg(nw_stats.receive_rate) AS avg_network_kb_s,
    avg(mstats.avg_center_nrt / 1000::double precision) AS avg_latency_to_hub_ms,
    avg(mstats.avg_inc_nrt / 1000::double precision) AS avg_incoming_latency_ms,
    max(log_stats.login_delay_ms) / 1000 AS peak_login_delay_s,
    max(mstats.cpu_peak_sys) AS peak_system_cpu_percent,
    max(mstats.cpu_peak_user) AS peak_user_cpu_percent,
    max(mstats.cpu_queue_peak) AS peak_cpu_queue_len,
    max(mstats.cpu_cswitch_peak) AS peak_cpu_context_switch_per_s,
    max(mstats.mem_peak / 1024::double precision) AS peak_mem_used_mb,
    max((mstats.mem_peak + mstats.swap_peak) / (mstats.mem_alloc + mstats.swap_alloc + 1::double precision) * 100::double precision) AS peak_mem_used_percent,
    max(disk_stats.peak_used / 1024::double precision) AS peak_disk_used_mb,
    max(disk_stats.read_peak + disk_stats.write_peak) AS peak_disk_iops,
    max(disk_stats.read_io_peak + disk_stats.write_io_peak) AS peak_disk_kb_s,
    max(disk_stats.queue_peak) AS peak_disk_queue_len,
    max(nw_stats.receive_rate) AS peak_network_kb_s,
    max(mstats.avg_center_nrt / 1000::double precision) AS peak_latency_to_hub_ms,
    max(mstats.avg_inc_nrt / 1000::double precision) AS peak_incoming_latency_ms
   FROM tnt_audit.summaryreports mstats
     JOIN tnt_config.policynode pmachine ON mstats.node_id = pmachine.id
     JOIN tnt_config.node nd ON mstats.node_id = nd.id
     JOIN tnt_audit.summaryreport_login_stats log_stats ON log_stats.node_id = mstats.node_id AND log_stats.start_date = mstats.start_date AND log_stats.end_date = mstats.end_date
     LEFT JOIN tnt_config.identitygroup_identity igroup ON log_stats.user_id = igroup.uid
     LEFT JOIN tnt_config.policyidentity usergroup ON igroup.groupid = usergroup.id
     LEFT JOIN tnt_audit.summaryreport_nic_stats nw_stats ON nw_stats.node_id = mstats.node_id AND nw_stats.start_date = mstats.start_date AND nw_stats.end_date = mstats.end_date
     LEFT JOIN tnt_audit.summaryreport_partition_stats disk_stats ON disk_stats.node_id = mstats.node_id AND disk_stats.start_date = mstats.start_date AND disk_stats.end_date = mstats.end_date
  GROUP BY log_stats.name, usergroup.name, mstats.start_date, mstats.end_date;
create view lwl_query.machine_performance as
 SELECT pmachine.name AS machine_name,
    machinegroup.name AS machine_group,
    mstats.start_date AS inspect_start_time_utc,
    mstats.end_date AS inspect_end_time_utc,
    avg(mstats.vdi_fit_overall) AS vdi_fit,
    avg(mstats.vdi_ux_overall) AS vdi_ux,
    count(DISTINCT log_stats.name) AS num_users,
    avg(log_stats.login_delay_ms) / 1000::numeric AS avg_login_delay_s,
    avg(mstats.cpu_avg_sys) AS avg_system_cpu_percent,
    avg(mstats.cpu_avg_user) AS avg_user_cpu_percent,
    avg(mstats.cpu_queue_avg) AS avg_cpu_queue_len,
    avg(mstats.cpu_cswitch_avg) AS avg_cpu_context_switch_per_s,
    avg((mstats.mem_avg + mstats.swap_avg) / 1024::double precision) AS avg_mem_used_mb,
    avg((mstats.mem_avg + mstats.swap_avg) / (mstats.mem_alloc + mstats.swap_alloc + 1::double precision) * 100::double precision) AS avg_mem_used_percent,
    avg(disk_stats.avg_used / 1024::double precision) AS avg_disk_used_mb,
    avg(disk_stats.read_avg + disk_stats.write_avg) AS avg_disk_iops,
    avg(disk_stats.read_io_avg + disk_stats.write_io_avg) AS avg_disk_kb_s,
    avg(disk_stats.queue_avg) AS avg_disk_queue_len,
    avg(nw_stats.receive_rate) AS avg_network_kb_s,
    avg(mstats.avg_center_nrt / 1000::double precision) AS avg_latency_to_hub_ms,
    avg(mstats.avg_inc_nrt / 1000::double precision) AS avg_incoming_latency_ms,
    max(log_stats.login_delay_ms) / 1000 AS peak_login_delay_s,
    max(mstats.cpu_peak_sys) AS peak_system_cpu_percent,
    max(mstats.cpu_peak_user) AS peak_user_cpu_percent,
    max(mstats.cpu_queue_peak) AS peak_cpu_queue_len,
    max(mstats.cpu_cswitch_peak) AS peak_cpu_context_switch_per_s,
    max(mstats.mem_peak / 1024::double precision) AS peak_mem_used_mb,
    max((mstats.mem_peak + mstats.swap_peak) / (mstats.mem_alloc + mstats.swap_alloc + 1::double precision) * 100::double precision) AS peak_mem_used_percent,max(disk_stats.peak_used / 1024::double precision) AS peak_disk_used_mb,
    max(disk_stats.read_peak + disk_stats.write_peak) AS peak_disk_iops,
    max(disk_stats.read_io_peak + disk_stats.write_io_peak) AS peak_disk_kb_s,
    max(disk_stats.queue_peak) AS peak_disk_queue_len,
    max(nw_stats.receive_rate) AS peak_network_kb_s,
    max(mstats.avg_center_nrt / 1000::double precision) AS peak_latency_to_hub_ms,
    max(mstats.avg_inc_nrt / 1000::double precision) AS peak_incoming_latency_ms
   FROM tnt_audit.summaryreports mstats
     JOIN tnt_config.policynode pmachine ON mstats.node_id = pmachine.id
     LEFT JOIN tnt_config.nodegroup_node ngroup ON mstats.node_id = ngroup.nodeid
     LEFT JOIN tnt_config.policynode machinegroup ON ngroup.nodegroupid = machinegroup.id
     LEFT JOIN tnt_audit.summaryreport_login_stats log_stats ON log_stats.node_id = mstats.node_id AND log_stats.start_date = mstats.start_date AND log_stats. end_date = mstats.end_date
     LEFT JOIN tnt_audit.summaryreport_nic_stats nw_stats ON nw_stats.node_id = mstats.node_id AND nw_stats.start_date = mstats.start_date AND nw_stats.end_date = mstats.end_date
     LEFT JOIN tnt_audit.summaryreport_partition_stats disk_stats ON disk_stats.node_id = mstats.node_id AND disk_stats.start_date = mstats.start_date AND disk_stats.end_date = mstats.end_date
  GROUP BY pmachine.name, machinegroup.name, mstats.start_date, mstats.end_date;
Grant select on lwl_query.machine_performance to "query";
Grant select on lwl_query.user_performance to "query";
