drop index if exists tnt_config.node_application_desk_app_idx;
create index node_application_desk_app_idx on tnt_config.node_application (desktop_app_id);
drop index if exists tnt_config.node_application_node_idx;
create index node_application_node_idx on tnt_config.node_application (node_id);

-- move some app logic to triggers

-- sid
create or replace function set_machine_sid() returns trigger as $set_machine_sid$
declare
	maxSid int;
	checkSid int;
	sidCount int;
begin
	maxSid := 1 << 20;
	IF NEW.sid is null then
		while true loop
			checkSid := (maxSid * random())::int;
			select into sidCount count(*) from tnt_config.node where sid = checkSid;
			if sidCount = 0 then
				exit;
			end if;
		end loop;
		NEW.sid := checkSid;
	end if;

	return NEW;
end;
$set_machine_sid$ LANGUAGE plpgsql;
drop trigger if exists set_sid on tnt_config.node;
--CREATE TRIGGER set_sid BEFORE INSERT ON tnt_config.node 
--    FOR EACH ROW EXECUTE PROCEDURE set_machine_sid();

-- uid
create or replace function set_user_uid() returns trigger as $set_user_uid$
declare
	maxUid int;
	checkUid int;
	uidCount int;
begin
	maxUid := 1 << 20;
	IF NEW.uid is null then
		while true loop
			checkUid := (maxUid * random())::int;
			select into uidCount count(*) from tnt_config.identity where uid = checkUid;
			if uidCount = 0 then
				exit;
			end if;
		end loop;
		NEW.uid := checkUid;
	end if;

	return NEW;
end;
$set_user_uid$ LANGUAGE plpgsql;
drop trigger if exists set_uid on tnt_config.identity;
--CREATE TRIGGER set_uid BEFORE INSERT ON tnt_config.identity
 --   FOR EACH ROW EXECUTE PROCEDURE set_user_uid();

-- clearing activation code
create or replace function clear_conflicting_hwprofile() returns trigger as $clear_conflicting_hwprofile$
declare
	nonPersistOn boolean;
begin
	if NEW.activationcode is not null then
		select into nonPersistOn is_vm_view_non_persist from tnt_config.globaloptions;
		if nonPersistOn then
			if NEW.id is null then
				update tnt_config.node set activationcode = null where delete_time is null;
			else
				update tnt_config.node set activationcode = null where delete_time is null and id != NEW.id;
			end if;
		end if;
	end if;
	return NEW;
end;
$clear_conflicting_hwprofile$ LANGUAGE plpgsql;
drop trigger if exists clear_hwprofile on tnt_config.node;
--CREATE TRIGGER clear_hwprofile BEFORE INSERT OR UPDATE of activationcode ON tnt_config.node 
 --   FOR EACH ROW EXECUTE PROCEDURE clear_conflicting_hwprofile();

drop index if exists tnt_config.node_server_role_node_idx;
create index node_server_role_node_idx  on tnt_config.node_server_role (node_id);
drop index if exists tnt_config.node_server_role_role_idx;
create index node_server_role_role_idx  on tnt_config.node_server_role (role_id);

-- drop only rollup rules
delete from tnt_config.rollup_rules where applyto = 'OLD_DATA_ONLY';
-- but create columns those old rules would've created if not there
alter table tnt_audit.summaryreports add column if not exists app_graph_avg double precision;
alter table tnt_audit.summaryreports add column if not exists app_graph_avg_count integer;
alter table tnt_audit.summaryreports add column if not exists app_launch_delay_ms double precision;
alter table tnt_audit.summaryreports add column if not exists app_launch_delay_ms_count integer;
alter table tnt_audit.summaryreports add column if not exists app_launch_delay_1ms double precision;
alter table tnt_audit.summaryreports add column if not exists app_launch_delay_1ms_count integer;

-- no limits..
begin; alter table tnt_config.node alter COLUMN activationcode type text ; commit;
