create extension if not exists intarray;

-- Create a function that always returns the first non-NULL item
CREATE OR REPLACE FUNCTION public.first_agg ( anyelement, anyelement )
RETURNS anyelement LANGUAGE SQL IMMUTABLE STRICT AS $$
        SELECT $1;
$$;
 
-- And then wrap an aggregate around it
CREATE AGGREGATE public.FIRST (
        sfunc    = public.first_agg,
        basetype = anyelement,
        stype    = anyelement
);
 
-- Create a function that always returns the last non-NULL item
CREATE OR REPLACE FUNCTION public.last_agg ( anyelement, anyelement )
RETURNS anyelement LANGUAGE SQL IMMUTABLE STRICT AS $$
        SELECT $2;
$$;
 
-- And then wrap an aggregate around it
CREATE AGGREGATE public.LAST (
        sfunc    = public.last_agg,
        basetype = anyelement,
        stype    = anyelement
);


-- rename tables to new format
Create or Replace function "tnt_audit".rename_partition_to_partman(refTable text, partPattern text)
Returns void As
$$
DECLARE
        schemaTable text[];
	partitionName text;
	fullPartitionPattern text;
	targetTable text;
	targetExists boolean;
	partitionDate date;
BEGIN
	raise debug 'Processing reference table: %, pattern %', refTable, partPattern;
	schemaTable := regexp_split_to_array(refTable, E'\\.');
	fullPartitionPattern := schemaTable[2] || partPattern;
	for partitionName in select tablename from pg_tables where tablename ~ fullPartitionPattern and schemaname = schemaTable[1] loop
		select into partitionDate to_date((regexp_matches(partitionName, '_(\d+$)'))[1], 'YYYYMMDD');
		select into targetTable (schemaTable[2] || '_' || to_char(partitionDate, 'pYYYY_MM_DD'));
		select into targetExists count(*) = 1 from pg_tables where tableName = targetTable and schemaName = schemaTable[1];
		-- if the target exists, then copy data from legacy table into existing one and then delete
		-- might happen if legacy collectors are running for a bit
		raise debug 'Found table: %, date %, target %, target exists %', partitionName, partitionDate, targetTable, targetExists;
		if targetExists then
			execute 'insert into ' || schemaTable[1] || '.' || targetTable || ' select * from ' || schemaTable[1] || '.' || partitionName;
			execute 'drop table ' || schemaTable[1] || '.' || partitionName;
		else
			execute 'alter table ' || schemaTable[1] || '.' || partitionname || ' rename to ' || targetTable;
		end if;
	end loop;
END;
$$
Language plpgsql
Volatile
Called On Null Input
Security invoker;


-- now that we're using partman, init indexes on parent tables and setup for partman.. we don't migrate existing data, we'll let it slowly get purged out
-- so make sure contraints/indexes are on parent table now before setting up partman

-- start with connectattempt, we're back to just partioning by time now, not tn and time
create index connectattempt_connection_idx on tnt_audit.connectattempt (connection_id, has_app_details) WHERE has_app_details = true;
create index connectattempt_dst_ip_idx on tnt_audit.connectattempt (dst_ip);
create index connectattempt_dst_port_protocol_idx on tnt_audit.connectattempt (dst_port_icmp_code, protocol);
create index connectattempt_dst_sid_idx on tnt_audit.connectattempt (dst_sid);
create index connectattempt_end_time_idx on tnt_audit.connectattempt (end_time);
create index connectattempt_packet_time_idx on tnt_audit.connectattempt (packet_time);
create index connectattempt_src_ip_idx on tnt_audit.connectattempt (src_ip);
create index connectattempt_src_sid_idx on tnt_audit.connectattempt (src_sid);
create index connectattempt_src_uid_idx on tnt_audit.connectattempt (src_uid);
create index connectattempt_status_idx on tnt_audit.connectattempt (status);
create index connectattempt_tn_idx on tnt_audit.connectattempt (tn);
create index connectattempt_station_idx on tnt_audit.connectattempt (stationid);
-- rename existing
--select tnt_audit.rename_partition_to_partman('tnt_audit.connectattempt', '_\d+_\d+');
SELECT partman.create_parent('tnt_audit.connectattempt', 'packet_time', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.connectattempt'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- connecturl
create index connecturl_connection_id_idx on tnt_audit.connecturl (connection_id);
create index connecturl_url_id_idx on tnt_audit.connecturl (url_id);
--select tnt_audit.rename_partition_to_partman('tnt_audit.connecturl', '_\d+_\d+');
SELECT partman.create_parent('tnt_audit.connecturl', 'url_time', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.connecturl'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- connectinterval
create index connectinterval_connection_id_idx on tnt_audit.connectinterval (connection_id);
--select tnt_audit.rename_partition_to_partman('tnt_audit.connectinterval', '_\d+_\d+');
SELECT partman.create_parent('tnt_audit.connectinterval', 'interval_time', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.connectinterval'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- summaryreports
alter table tnt_audit.summaryreports add primary key (node_id, start_date, end_date);
create index summaryreports_app_idx on tnt_audit.summaryreports using gin(desktop_app_ids);
create index summaryreports_end_time_idx on tnt_audit.summaryreports (end_date); 
-- we do look at start_date for rollup
create index summaryreports_start_time_idx on tnt_audit.summaryreports (start_date); 
create index summaryreports_login_idx on tnt_audit.summaryreports using gin(login_ids);
create index summaryreports_node_idx on tnt_audit.summaryreports (node_id); 
create index summaryreports_rollup_idx on tnt_audit.summaryreports (rolled_up); 
--ALTER TABLE tnt_audit.summaryreports ADD CONSTRAINT nodefk FOREIGN KEY (node_id) REFERENCES tnt_config.policynode (id) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreports ADD CONSTRAINT vmhostfk FOREIGN KEY (vmhost_id) REFERENCES tnt_config.vmhost (id) on update cascade on delete set null;

select tnt_audit.rename_partition_to_partman('tnt_audit.summaryreports', '_');
SELECT partman.create_parent('tnt_audit.summaryreports', 'end_date', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.summaryreports'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- process stats
alter table tnt_audit.summaryreport_process_stats add primary key (node_id, start_date, end_date, pid, name);
create index summaryreports_prstat_app_idx on tnt_audit.summaryreport_process_stats (desk_app_id);
-- we do look at start_date for rollup
create index summaryreports_prstat_start_time_idx on tnt_audit.summaryreport_process_stats (start_date); 
create index summaryreports_prstat_end_time_idx on tnt_audit.summaryreport_process_stats (end_date);
create index summaryreports_prstat_node_idx on tnt_audit.summaryreport_process_stats (node_id);
create index summaryreports_prstat_node_time_idx on tnt_audit.summaryreport_process_stats (node_id, start_date, end_date);
--ALTER TABLE tnt_audit.summaryreport_process_stats ADD CONSTRAINT nodefk FOREIGN KEY (node_id) REFERENCES tnt_config.policynode (id) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreport_process_stats ADD CONSTRAINT srfk FOREIGN KEY (node_id, start_date, end_date) REFERENCES tnt_audit.summaryreports (node_id, start_date, end_date) on update cascade on delete cascade;

select tnt_audit.rename_partition_to_partman('tnt_audit.summaryreport_process_stats', '_');
SELECT partman.create_parent('tnt_audit.summaryreport_process_stats', 'end_date', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.summaryreport_process_stats'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- login stats
alter table tnt_audit.summaryreport_login_stats add primary key (node_id, start_date, end_date, name, login_time);
-- we do look at start_date for rollup
create index summaryreports_lgstat_start_time_idx on tnt_audit.summaryreport_login_stats (start_date); 
create index summaryreports_lgstat_end_time_idx on tnt_audit.summaryreport_login_stats (end_date);
create index summaryreports_lgstat_node_idx on tnt_audit.summaryreport_login_stats (node_id);
create index summaryreports_lgstat_node_time_idx on tnt_audit.summaryreport_login_stats (node_id, start_date, end_date);
create index summaryreports_lgstat_user_idx on tnt_audit.summaryreport_login_stats (user_id);
--ALTER TABLE tnt_audit.summaryreport_login_stats ADD CONSTRAINT nodefk FOREIGN KEY (node_id) REFERENCES tnt_config.policynode (id) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreport_login_stats ADD CONSTRAINT srfk FOREIGN KEY (node_id, start_date, end_date) REFERENCES tnt_audit.summaryreports (node_id, start_date, end_date) on update cascade on delete cascade;

select tnt_audit.rename_partition_to_partman('tnt_audit.summaryreport_login_stats', '_');
SELECT partman.create_parent('tnt_audit.summaryreport_login_stats', 'end_date', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.summaryreport_login_stats'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- partition stats
alter table tnt_audit.summaryreport_partition_stats add primary key (node_id, start_date, end_date, name, disk_id);
-- we do look at start_date for rollup
create index summaryreports_pastat_start_time_idx on tnt_audit.summaryreport_partition_stats (start_date); 
create index summaryreports_pastat_end_time_idx on tnt_audit.summaryreport_partition_stats (end_date);
create index summaryreports_pastat_node_idx on tnt_audit.summaryreport_partition_stats (node_id);
create index summaryreports_pastat_node_time_idx on tnt_audit.summaryreport_partition_stats (node_id, start_date, end_date);
--ALTER TABLE tnt_audit.summaryreport_partition_stats ADD CONSTRAINT nodefk FOREIGN KEY (node_id) REFERENCES tnt_config.policynode (id) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreport_partition_stats ADD CONSTRAINT vdfk FOREIGN KEY (vdisk_id) REFERENCES tnt_config.virtualdisk (id) on update cascade on delete set null;
--ALTER TABLE tnt_audit.summaryreport_partition_stats ADD CONSTRAINT dsfk FOREIGN KEY (vdisk_datastoreid) REFERENCES tnt_config.datastore (id) on update cascade on delete set null;
--ALTER TABLE tnt_audit.summaryreport_partition_stats ADD CONSTRAINT srfk FOREIGN KEY (node_id, start_date, end_date) REFERENCES tnt_audit.summaryreports (node_id, start_date, end_date) on update cascade on delete cascade;

select tnt_audit.rename_partition_to_partman('tnt_audit.summaryreport_partition_stats', '_');
SELECT partman.create_parent('tnt_audit.summaryreport_partition_stats', 'end_date', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.summaryreport_partition_stats'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- disk stats
alter table tnt_audit.summaryreport_disk_stats add primary key (node_id, start_date, end_date, name, disk_id);
-- we do look at start_date for rollup
create index summaryreports_dkstat_start_time_idx on tnt_audit.summaryreport_disk_stats (start_date); 
create index summaryreports_dkstat_end_time_idx on tnt_audit.summaryreport_disk_stats (end_date);
create index summaryreports_dkstat_node_idx on tnt_audit.summaryreport_disk_stats (node_id);
create index summaryreports_dkstat_node_time_idx on tnt_audit.summaryreport_disk_stats (node_id, start_date, end_date);
--ALTER TABLE tnt_audit.summaryreport_disk_stats ADD CONSTRAINT nodefk FOREIGN KEY (node_id) REFERENCES tnt_config.policynode (id) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreport_disk_stats ADD CONSTRAINT vdfk FOREIGN KEY (vdisk_id) REFERENCES tnt_config.virtualdisk (id) on update cascade on delete set null;
--ALTER TABLE tnt_audit.summaryreport_disk_stats ADD CONSTRAINT dsfk FOREIGN KEY (vdisk_datastoreid) REFERENCES tnt_config.datastore (id) on update cascade on delete set null;
--ALTER TABLE tnt_audit.summaryreport_disk_stats ADD CONSTRAINT srfk FOREIGN KEY (node_id, start_date, end_date) REFERENCES tnt_audit.summaryreports (node_id, start_date, end_date) on update cascade on delete cascade;

select tnt_audit.rename_partition_to_partman('tnt_audit.summaryreport_disk_stats', '_');
SELECT partman.create_parent('tnt_audit.summaryreport_disk_stats', 'end_date', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.summaryreport_disk_stats'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- ping stats
alter table tnt_audit.summaryreport_ping_stats add primary key (node_id, start_date, end_date, address, name);
-- we do look at start_date for rollup
create index summaryreports_pgstat_start_time_idx on tnt_audit.summaryreport_ping_stats (start_date); 
create index summaryreports_pgstat_end_time_idx on tnt_audit.summaryreport_ping_stats (end_date);
create index summaryreports_pgstat_node_idx on tnt_audit.summaryreport_ping_stats (node_id);
create index summaryreports_pgstat_node_time_idx on tnt_audit.summaryreport_ping_stats (node_id, start_date, end_date);
create index summaryreports_pgstat_address_idx on tnt_audit.summaryreport_ping_stats (address);
--ALTER TABLE tnt_audit.summaryreport_ping_stats ADD CONSTRAINT nodefk FOREIGN KEY (node_id) REFERENCES tnt_config.policynode (id) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreport_ping_stats ADD CONSTRAINT srfk FOREIGN KEY (node_id, start_date, end_date) REFERENCES tnt_audit.summaryreports (node_id, start_date, end_date) on update cascade on delete cascade;

select tnt_audit.rename_partition_to_partman('tnt_audit.summaryreport_ping_stats', '_');
SELECT partman.create_parent('tnt_audit.summaryreport_ping_stats', 'end_date', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.summaryreport_ping_stats'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- nic stats
alter table tnt_audit.summaryreport_nic_stats add primary key (node_id, start_date, end_date, name);
-- we do look at start_date for rollup
create index summaryreports_ncstat_start_time_idx on tnt_audit.summaryreport_nic_stats (start_date); 
create index summaryreports_ncstat_end_time_idx on tnt_audit.summaryreport_nic_stats (end_date);
create index summaryreports_ncstat_node_idx on tnt_audit.summaryreport_nic_stats (node_id);
create index summaryreports_ncstat_node_time_idx on tnt_audit.summaryreport_nic_stats (node_id, start_date, end_date);
--ALTER TABLE tnt_audit.summaryreport_nic_stats ADD CONSTRAINT nodefk FOREIGN KEY (node_id) REFERENCES tnt_config.policynode (id) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreport_nic_stats ADD CONSTRAINT srfk FOREIGN KEY (node_id, start_date, end_date) REFERENCES tnt_audit.summaryreports (node_id, start_date, end_date) on update cascade on delete cascade;

select tnt_audit.rename_partition_to_partman('tnt_audit.summaryreport_nic_stats', '_');
SELECT partman.create_parent('tnt_audit.summaryreport_nic_stats', 'end_date', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.summaryreport_nic_stats'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- gpu stats
alter table tnt_audit.summaryreport_gpu_stats add primary key (node_id, start_date, end_date, node_hardware_gpu_id);
-- we do look at start_date for rollup
create index summaryreports_gpstat_start_time_idx on tnt_audit.summaryreport_gpu_stats (start_date); 
create index summaryreports_gpstat_end_time_idx on tnt_audit.summaryreport_gpu_stats (end_date);
create index summaryreports_gpstat_node_idx on tnt_audit.summaryreport_gpu_stats (node_id);
create index summaryreports_gpstat_node_time_idx on tnt_audit.summaryreport_gpu_stats (node_id, start_date, end_date);
--ALTER TABLE tnt_audit.summaryreport_gpu_stats ADD CONSTRAINT nodefk FOREIGN KEY (node_id) REFERENCES tnt_config.policynode (id) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreport_gpu_stats ADD CONSTRAINT srfk FOREIGN KEY (node_id, start_date, end_date) REFERENCES tnt_audit.summaryreports (node_id, start_date, end_date) on update cascade on delete cascade;

select tnt_audit.rename_partition_to_partman('tnt_audit.summaryreport_gpu_stats', '_');
SELECT partman.create_parent('tnt_audit.summaryreport_gpu_stats', 'end_date', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.summaryreport_gpu_stats'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- display stats
alter table tnt_audit.summaryreport_display_proto_stats add primary key (node_id, start_date, end_date, session_start, type);
-- we do look at start_date for rollup
create index summaryreports_dpstat_start_time_idx on tnt_audit.summaryreport_display_proto_stats (start_date); 
create index summaryreports_dpstat_end_time_idx on tnt_audit.summaryreport_display_proto_stats (end_date);
create index summaryreports_dpstat_node_idx on tnt_audit.summaryreport_display_proto_stats (node_id);
create index summaryreports_dpstat_node_time_idx on tnt_audit.summaryreport_display_proto_stats (node_id, start_date, end_date);
create index summaryreports_dpstat_user_idx on tnt_audit.summaryreport_display_proto_stats (user_id);
--ALTER TABLE tnt_audit.summaryreport_display_proto_stats ADD CONSTRAINT nodefk FOREIGN KEY (node_id) REFERENCES tnt_config.policynode (id) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreport_display_proto_stats ADD CONSTRAINT srfk FOREIGN KEY (node_id, start_date, end_date) REFERENCES tnt_audit.summaryreports (node_id, start_date, end_date) on update cascade on delete cascade;

select tnt_audit.rename_partition_to_partman('tnt_audit.summaryreport_display_proto_stats', '_');
SELECT partman.create_parent('tnt_audit.summaryreport_display_proto_stats', 'end_date', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.summaryreport_display_proto_stats'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- browser stats
alter table tnt_audit.summaryreport_browser_stats add primary key (node_id, start_date, end_date, type);
-- we do look at start_date for rollup
create index summaryreports_brstat_start_time_idx on tnt_audit.summaryreport_browser_stats (start_date); 
create index summaryreports_brstat_end_time_idx on tnt_audit.summaryreport_browser_stats (end_date);
create index summaryreports_brstat_node_idx on tnt_audit.summaryreport_browser_stats (node_id);
create index summaryreports_brstat_node_time_idx on tnt_audit.summaryreport_browser_stats (node_id, start_date, end_date);
--ALTER TABLE tnt_audit.summaryreport_browser_stats ADD CONSTRAINT nodefk FOREIGN KEY (node_id) REFERENCES tnt_config.policynode (id) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreport_browser_stats ADD CONSTRAINT srfk FOREIGN KEY (node_id, start_date, end_date) REFERENCES tnt_audit.summaryreports (node_id, start_date, end_date) on update cascade on delete cascade;

select tnt_audit.rename_partition_to_partman('tnt_audit.summaryreport_browser_stats', '_');
SELECT partman.create_parent('tnt_audit.summaryreport_browser_stats', 'end_date', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.summaryreport_browser_stats'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- browser tab stats
-- we do look at start_date for rollup
create index summaryreports_brtstat_start_time_idx on tnt_audit.summaryreport_browser_tab_stats (start_date); 
create index summaryreports_brtstat_end_time_idx on tnt_audit.summaryreport_browser_tab_stats (end_date);
create index summaryreports_brtstat_node_idx on tnt_audit.summaryreport_browser_tab_stats (node_id);
create index summaryreports_brtstat_node_time_idx on tnt_audit.summaryreport_browser_tab_stats (node_id, start_date, end_date);
--ALTER TABLE tnt_audit.summaryreport_browser_tab_stats ADD CONSTRAINT nodefk FOREIGN KEY (node_id) REFERENCES tnt_config.policynode (id) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreport_browser_tab_stats ADD CONSTRAINT brfk FOREIGN KEY (node_id, start_date, end_date, type) REFERENCES tnt_audit.summaryreport_browser_stats (node_id, start_date, end_date, type) on update cascade on delete cascade;

select tnt_audit.rename_partition_to_partman('tnt_audit.summaryreport_browser_tab_stats', '_');
SELECT partman.create_parent('tnt_audit.summaryreport_browser_tab_stats', 'end_date', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.summaryreport_browser_tab_stats'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- browser extension stats
-- we do look at start_date for rollup
create index summaryreports_brestat_start_time_idx on tnt_audit.summaryreport_browser_extension_stats (start_date); 
create index summaryreports_brestat_end_time_idx on tnt_audit.summaryreport_browser_extension_stats (end_date);
create index summaryreports_brestat_node_idx on tnt_audit.summaryreport_browser_extension_stats (node_id);
create index summaryreports_brestat_node_time_idx on tnt_audit.summaryreport_browser_extension_stats (node_id, start_date, end_date);
--ALTER TABLE tnt_audit.summaryreport_browser_extension_stats ADD CONSTRAINT nodefk FOREIGN KEY (node_id) REFERENCES tnt_config.policynode (id) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreport_browser_extension_stats ADD CONSTRAINT brfk FOREIGN KEY (node_id, start_date, end_date, type) REFERENCES tnt_audit.summaryreport_browser_stats (node_id, start_date, end_date, type) on update cascade on delete cascade;

select tnt_audit.rename_partition_to_partman('tnt_audit.summaryreport_browser_extension_stats', '_');
SELECT partman.create_parent('tnt_audit.summaryreport_browser_extension_stats', 'end_date', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.summaryreport_browser_extension_stats'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- browser process stats
-- we do look at start_date for rollup
create index summaryreports_brpstat_start_time_idx on tnt_audit.summaryreport_browser_process_stats (start_date); 
create index summaryreports_brpstat_end_time_idx on tnt_audit.summaryreport_browser_process_stats (end_date);
create index summaryreports_brpstat_node_idx on tnt_audit.summaryreport_browser_process_stats (node_id);
create index summaryreports_brpstat_node_time_idx on tnt_audit.summaryreport_browser_process_stats (node_id, start_date, end_date);
--ALTER TABLE tnt_audit.summaryreport_browser_process_stats ADD CONSTRAINT nodefk FOREIGN KEY (node_id) REFERENCES tnt_config.policynode (id) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreport_browser_process_stats ADD CONSTRAINT brfk FOREIGN KEY (node_id, start_date, end_date, type) REFERENCES tnt_audit.summaryreport_browser_stats (node_id, start_date, end_date, type) on update cascade on delete cascade;
select tnt_audit.rename_partition_to_partman('tnt_audit.summaryreport_browser_process_stats', '_');
SELECT partman.create_parent('tnt_audit.summaryreport_browser_process_stats', 'end_date', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.summaryreport_browser_process_stats'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- login_event stats
-- we do look at start_date for rollup
create index summaryreports_lgestat_start_time_idx on tnt_audit.summaryreport_login_event_stats (start_date); 
create index summaryreports_lgestat_end_time_idx on tnt_audit.summaryreport_login_event_stats (end_date);
create index summaryreports_lgestat_node_idx on tnt_audit.summaryreport_login_event_stats (node_id);
create index summaryreports_lgestat_node_time_idx on tnt_audit.summaryreport_login_event_stats (node_id, start_date, end_date);
create index summaryreports_lgestat_login_idx on tnt_audit.summaryreport_login_event_stats (node_id, start_date, end_date, name, login_time);
create index summaryreports_lgestat_evt_idx on tnt_audit.summaryreport_login_event_stats (event_name);
--ALTER TABLE tnt_audit.summaryreport_login_event_stats ADD CONSTRAINT nodefk FOREIGN KEY (node_id) REFERENCES tnt_config.policynode (id) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreport_login_event_stats ADD CONSTRAINT lgfk FOREIGN KEY (node_id, start_date, end_date, name, login_time) REFERENCES tnt_audit.summaryreport_login_stats (node_id, start_date, end_date, name, login_time) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreport_login_event_stats ADD CONSTRAINT srfk FOREIGN KEY (node_id, start_date, end_date) REFERENCES tnt_audit.summaryreports (node_id, start_date, end_date) on update cascade on delete cascade;
select tnt_audit.rename_partition_to_partman('tnt_audit.summaryreport_login_event_stats', '_');
SELECT partman.create_parent('tnt_audit.summaryreport_login_event_stats', 'end_date', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.summaryreport_login_event_stats'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- login_session stats
alter table tnt_audit.summaryreport_login_session_stats add primary key (node_id, start_date, end_date, name, login_time, event_time, event_type);
-- we do look at start_date for rollup
create index summaryreports_lgsstat_start_time_idx on tnt_audit.summaryreport_login_session_stats (start_date); 
create index summaryreports_lgsstat_end_time_idx on tnt_audit.summaryreport_login_session_stats (end_date);
create index summaryreports_lgsstat_node_idx on tnt_audit.summaryreport_login_session_stats (node_id);
create index summaryreports_lgsstat_node_time_idx on tnt_audit.summaryreport_login_session_stats (node_id, start_date, end_date);
create index summaryreports_lgsstat_login_idx on tnt_audit.summaryreport_login_session_stats (node_id, start_date, end_date, name, login_time);
create index summaryreports_lgsstat_evt_idx on tnt_audit.summaryreport_login_session_stats (event_type);
create index summaryreports_lgsstat_sum_idx on tnt_audit.summaryreport_login_session_stats (summarized);
--ALTER TABLE tnt_audit.summaryreport_login_session_stats ADD CONSTRAINT nodefk FOREIGN KEY (node_id) REFERENCES tnt_config.policynode (id) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreport_login_session_stats ADD CONSTRAINT lgfk FOREIGN KEY (node_id, start_date, end_date, name, login_time) REFERENCES tnt_audit.summaryreport_login_stats (node_id, start_date, end_date, name, login_time) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreport_login_session_stats ADD CONSTRAINT srfk FOREIGN KEY (node_id, start_date, end_date) REFERENCES tnt_audit.summaryreports (node_id, start_date, end_date) on update cascade on delete cascade;

select tnt_audit.rename_partition_to_partman('tnt_audit.summaryreport_login_session_stats', '_');
SELECT partman.create_parent('tnt_audit.summaryreport_login_session_stats', 'end_date', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.summaryreport_login_session_stats'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- traceroute stats
alter table tnt_audit.summaryreport_traceroute_stats add primary key (node_id, start_date, end_date, input, port);
-- we do look at start_date for rollup
create index summaryreports_trstat_start_time_idx on tnt_audit.summaryreport_traceroute_stats (start_date); 
create index summaryreports_trstat_end_time_idx on tnt_audit.summaryreport_traceroute_stats (end_date);
create index summaryreports_trstat_node_idx on tnt_audit.summaryreport_traceroute_stats (node_id);
create index summaryreports_trstat_node_time_idx on tnt_audit.summaryreport_traceroute_stats (node_id, start_date, end_date);
create index summaryreports_trstat_name_idx on tnt_audit.summaryreport_traceroute_stats (name);
--ALTER TABLE tnt_audit.summaryreport_traceroute_stats ADD CONSTRAINT nodefk FOREIGN KEY (node_id) REFERENCES tnt_config.policynode (id) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreport_traceroute_stats ADD CONSTRAINT srfk FOREIGN KEY (node_id, start_date, end_date) REFERENCES tnt_audit.summaryreports (node_id, start_date, end_date) on update cascade on delete cascade;

select tnt_audit.rename_partition_to_partman('tnt_audit.summaryreport_traceroute_stats', '_');
SELECT partman.create_parent('tnt_audit.summaryreport_traceroute_stats', 'end_date', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.summaryreport_traceroute_stats'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- folder stats
alter table tnt_audit.summaryreport_folder_stats add primary key (node_id, start_date, end_date, name, cfgname);
-- we do look at start_date for rollup
create index summaryreports_fsstat_start_time_idx on tnt_audit.summaryreport_folder_stats (start_date); 
create index summaryreports_fsstat_end_time_idx on tnt_audit.summaryreport_folder_stats (end_date);
create index summaryreports_fsstat_node_idx on tnt_audit.summaryreport_folder_stats (node_id);
create index summaryreports_fsstat_node_time_idx on tnt_audit.summaryreport_folder_stats (node_id, start_date, end_date);
create index summaryreports_fsstat_cfgname_idx on tnt_audit.summaryreport_folder_stats (cfgname);
--ALTER TABLE tnt_audit.summaryreport_folder_stats ADD CONSTRAINT nodefk FOREIGN KEY (node_id) REFERENCES tnt_config.policynode (id) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreport_folder_stats ADD CONSTRAINT srfk FOREIGN KEY (node_id, start_date, end_date) REFERENCES tnt_audit.summaryreports (node_id, start_date, end_date) on update cascade on delete cascade;

select tnt_audit.rename_partition_to_partman('tnt_audit.summaryreport_folder_stats', '_');
SELECT partman.create_parent('tnt_audit.summaryreport_folder_stats', 'end_date', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.summaryreport_folder_stats'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

-- folder ext stats
alter table tnt_audit.summaryreport_folder_ext_stats add primary key (node_id, start_date, end_date, folder_name, name, folder_cfgname);
-- we do look at start_date for rollup
create index summaryreports_fsestat_start_time_idx on tnt_audit.summaryreport_folder_ext_stats (start_date); 
create index summaryreports_fsestat_end_time_idx on tnt_audit.summaryreport_folder_ext_stats (end_date);
create index summaryreports_fsestat_node_idx on tnt_audit.summaryreport_folder_ext_stats (node_id);
create index summaryreports_fsestat_node_time_idx on tnt_audit.summaryreport_folder_ext_stats (node_id, start_date, end_date);
create index summaryreports_fsestat_name_idx on tnt_audit.summaryreport_folder_ext_stats (name);
--ALTER TABLE tnt_audit.summaryreport_folder_ext_stats ADD CONSTRAINT nodefk FOREIGN KEY (node_id) REFERENCES tnt_config.policynode (id) on update cascade on delete cascade;
--ALTER TABLE tnt_audit.summaryreport_folder_ext_stats ADD CONSTRAINT fsfk FOREIGN KEY (node_id, start_date, end_date,name,folder_cfgname) REFERENCES tnt_audit.summaryreport_folder_stats (node_id, start_date, end_date, name, cfgname) on update cascade on delete cascade;

select tnt_audit.rename_partition_to_partman('tnt_audit.summaryreport_folder_ext_stats', '_');
SELECT partman.create_parent('tnt_audit.summaryreport_folder_ext_stats', 'end_date', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.summaryreport_folder_ext_stats'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

create schema lwl_rollup;
GRANT ALL ON SCHEMA lwl_rollup TO impadmin;
GRANT USAGE ON SCHEMA lwl_rollup TO reports;

CREATE AGGREGATE hstore_sum (hstore) (
    SFUNC = hs_concat(hstore, hstore),
    STYPE = hstore
);

create or replace function public.array_unique(arr anyarray)
returns anyarray as $body$
    select array( select distinct unnest($1) )
$body$ language 'sql';

drop function tnt_audit.rename_partition_to_partman(text, text);
