-- rename tables to new format
Create or Replace function "tnt_audit".rename_partition_to_partman(refTable text, partPattern text)
Returns void As
$$
DECLARE
        schemaTable text[];
	partitionName text;
	fullPartitionPattern text;
	targetTable text;
	targetExists boolean;
	partitionDate date;
BEGIN
	raise debug 'Processing reference table: %, pattern %', refTable, partPattern;
	schemaTable := regexp_split_to_array(refTable, E'\\.');
	fullPartitionPattern := schemaTable[2] || partPattern;
	for partitionName in select tablename from pg_tables where tablename ~ fullPartitionPattern and schemaname = schemaTable[1] loop
		select into partitionDate to_date((regexp_matches(partitionName, '_(\d+$)'))[1], 'YYYYMMDD');
		select into targetTable (schemaTable[2] || '_' || to_char(partitionDate, 'pYYYY_MM_DD'));
		select into targetExists count(*) = 1 from pg_tables where tableName = targetTable and schemaName = schemaTable[1];
		-- if the target exists, then copy data from legacy table into existing one and then delete
		-- might happen if legacy collectors are running for a bit
		raise debug 'Found table: %, date %, target %, target exists %', partitionName, partitionDate, targetTable, targetExists;
		if targetExists then
			execute 'insert into ' || schemaTable[1] || '.' || targetTable || ' select * from ' || schemaTable[1] || '.' || partitionName;
			execute 'drop table ' || schemaTable[1] || '.' || partitionName;
		else
			execute 'alter table ' || schemaTable[1] || '.' || partitionname || ' rename to ' || targetTable;
		end if;
	end loop;
END;
$$
Language plpgsql
Volatile
Called On Null Input
Security invoker;

alter table tnt_audit.hoststats add primary key (vmhost_id, start_date, end_date);
create index hoststats_start_time_idx  on tnt_audit.hoststats (start_date); 
create index hoststats_end_time_idx  on tnt_audit.hoststats (end_date); 
create index hoststats_vmhost_idx  on tnt_audit.hoststats (vmhost_id); 
alter table tnt_audit.hoststats add column rolled_up boolean default false;

select tnt_audit.rename_partition_to_partman('tnt_audit.hoststats', '_');
SELECT partman.create_parent('tnt_audit.hoststats', 'end_date', (case when (select count(*) from pg_partitioned_table where partrelid = (select 'tnt_audit.hoststats'::regclass::oid)) > 0 then 'native' else 'partman' end), 'daily');

drop function tnt_audit.rename_partition_to_partman(text, text);
