drop table if exists "tnt_audit"."summaryreport_machine_health_stats" cascade;
-- manually cleanup partman
delete from partman.part_config where parent_table = 'tnt_audit.summaryreport_machine_health_stats';
Create table if not exists "tnt_audit"."summaryreport_machine_health_stats"
(
	"node_id" Integer NOT NULL,
	"start_date" Timestamp NOT NULL,
	"end_date" Timestamp NOT NULL,

	"os_update_status" bool,
	"os_update_last_check" timestamp,
	"os_update_last_update" timestamp,
	"os_update_pending_count" int, 

	"fw_status" bool,
	"fw_provider" text,
	"fw_public_status" bool,
	"fw_private_status" bool,
	"fw_domain_status" bool,

	"sec_coreiso_memintegrity_status" text,
	"sec_sproc_attestation_status" text,
	"sec_sproc_storage_status" text,
	"sec_cred_guard" text,
	"sec_dev_guard" text,
	"sec_secure_boot" text,

	primary key (node_id, start_date, end_date)
) partition by range (end_date) Without Oids;

-- we do look at start_date for rollup
create index if not exists summaryreports_mach_health_end_time_idx on tnt_audit.summaryreport_machine_health_stats (end_date);
create index if not exists summaryreports_mach_health_node_idx on tnt_audit.summaryreport_machine_health_stats (node_id);
-- for other things
--create index if not exists summaryreports_mach_health_nname_idx on tnt_audit.summaryreport_machine_health_stats (network_name);

ALTER TABLE tnt_audit.summaryreport_machine_health_stats OWNER TO impadmin;
REVOKE ALL ON TABLE tnt_audit.summaryreport_machine_health_stats FROM PUBLIC;
REVOKE ALL ON TABLE tnt_audit.summaryreport_machine_health_stats FROM impadmin;
GRANT ALL ON TABLE tnt_audit.summaryreport_machine_health_stats TO impadmin;
GRANT SELECT ON TABLE tnt_audit.summaryreport_machine_health_stats TO reports;
GRANT SELECT ON TABLE tnt_audit.summaryreport_machine_health_stats TO vcops;

SELECT partman.create_parent('tnt_audit.summaryreport_machine_health_stats', 'end_date', 'native', 'daily');
select partman.create_partition_time('tnt_audit.summaryreport_machine_health_stats', ARRAY[date_trunc('day', now())]);

drop table if exists "tnt_audit"."summaryreport_machine_health_software_stats" cascade;
-- manually cleanup partman
delete from partman.part_config where parent_table = 'tnt_audit.summaryreport_machine_health_software_stats';
Create table if not exists "tnt_audit"."summaryreport_machine_health_software_stats"
(
	"node_id" Integer NOT NULL,
	"start_date" Timestamp NOT NULL,
	"end_date" Timestamp NOT NULL,
	"type" text NOT NULL,

	"enabled" bool,
	"provider" text not null,
	"last_scan_time" timestamp,
	"last_sig_update_time" timestamp,
	"threat_count" int,

	primary key (node_id, start_date, end_date, type, provider)
) partition by range (end_date) Without Oids;

-- we do look at start_date for rollup
create index if not exists summaryreports_mach_health_soft_rpt_idx on tnt_audit.summaryreport_machine_health_software_stats (node_id, start_date, end_date);
create index if not exists summaryreports_mach_health_soft_type_idx on tnt_audit.summaryreport_machine_health_software_stats (type);
create index if not exists summaryreports_mach_health_soft_prv_idx on tnt_audit.summaryreport_machine_health_software_stats (provider);
create index if not exists summaryreports_mach_health_soft_end_time_idx on tnt_audit.summaryreport_machine_health_software_stats (end_date);
create index if not exists summaryreports_mach_health_soft_node_idx on tnt_audit.summaryreport_machine_health_software_stats (node_id);
-- for other things
--create index if not exists summaryreports_mach_health_soft_nname_idx on tnt_audit.summaryreport_machine_health_software_stats (network_name);

ALTER TABLE tnt_audit.summaryreport_machine_health_software_stats OWNER TO impadmin;
REVOKE ALL ON TABLE tnt_audit.summaryreport_machine_health_software_stats FROM PUBLIC;
REVOKE ALL ON TABLE tnt_audit.summaryreport_machine_health_software_stats FROM impadmin;
GRANT ALL ON TABLE tnt_audit.summaryreport_machine_health_software_stats TO impadmin;
GRANT SELECT ON TABLE tnt_audit.summaryreport_machine_health_software_stats TO reports;
GRANT SELECT ON TABLE tnt_audit.summaryreport_machine_health_software_stats TO vcops;

SELECT partman.create_parent('tnt_audit.summaryreport_machine_health_software_stats', 'end_date', 'native', 'daily');
select partman.create_partition_time('tnt_audit.summaryreport_machine_health_software_stats', ARRAY[date_trunc('day', now())]);

drop table if exists "tnt_audit"."summaryreport_machine_health_disk_stats" cascade;
-- manually cleanup partman
delete from partman.part_config where parent_table = 'tnt_audit.summaryreport_machine_health_disk_stats';
Create table if not exists "tnt_audit"."summaryreport_machine_health_disk_stats"
(
	"node_id" Integer NOT NULL,
	"start_date" Timestamp NOT NULL,
	"end_date" Timestamp NOT NULL,
	"name" text NOT NULL,

	"encrypted" bool,
	"provider" text,

	primary key (node_id, start_date, end_date, name)
) partition by range (end_date) Without Oids;

-- we do look at start_date for rollup
create index if not exists summaryreports_mach_health_dsk_rpt_idx on tnt_audit.summaryreport_machine_health_disk_stats (node_id, start_date, end_date);
create index if not exists summaryreports_mach_health_dsk_prv_idx on tnt_audit.summaryreport_machine_health_disk_stats (provider);
create index if not exists summaryreports_mach_health_dsk_end_time_idx on tnt_audit.summaryreport_machine_health_disk_stats (end_date);
create index if not exists summaryreports_mach_health_dsk_node_idx on tnt_audit.summaryreport_machine_health_disk_stats (node_id);
-- for other things
--create index if not exists summaryreports_mach_health_dsk_nname_idx on tnt_audit.summaryreport_machine_health_disk_stats (network_name);

ALTER TABLE tnt_audit.summaryreport_machine_health_disk_stats OWNER TO impadmin;
REVOKE ALL ON TABLE tnt_audit.summaryreport_machine_health_disk_stats FROM PUBLIC;
REVOKE ALL ON TABLE tnt_audit.summaryreport_machine_health_disk_stats FROM impadmin;
GRANT ALL ON TABLE tnt_audit.summaryreport_machine_health_disk_stats TO impadmin;
GRANT SELECT ON TABLE tnt_audit.summaryreport_machine_health_disk_stats TO reports;
GRANT SELECT ON TABLE tnt_audit.summaryreport_machine_health_disk_stats TO vcops;

SELECT partman.create_parent('tnt_audit.summaryreport_machine_health_disk_stats', 'end_date', 'native', 'daily');
select partman.create_partition_time('tnt_audit.summaryreport_machine_health_disk_stats', ARRAY[date_trunc('day', now())]);
