-- add password table
drop table if exists tnt_config.passwords;
create table tnt_config.passwords (
        id serial primary key,
        creation_time timestamp not null default current_timestamp,
	deletion_time timestamp,
	expiration_time timestamp,
        password text not null,
        type text,
        associated_object_id integer not null
) Without Oids;
alter table tnt_config.passwords owner to impadmin;
grant select on table tnt_config.passwords to reports;
create index type_assc_obj_id_idx on tnt_config.passwords (type, associated_object_id);
-- can only have one undeleted password for any given type and object id
create unique index cur_type_assc_obj_id_idx on tnt_config.passwords (type, associated_object_id) where deletion_time is null;
Create or Replace function "tnt_config".copy_user_passwords()
Returns void As
' 
DECLARE
        vTable record;
BEGIN
        FOR vTable in select pi.id, id.passphrase from tnt_config.policyidentity pi, tnt_config.identity id where pi.id = id.id and pi.delete_time is null and id.passphrase is not null and pi.type = 1 and pi.system_object is false LOOP
                raise notice ''Copying passphrase for %'', vTable.id;   
		execute ''insert into tnt_config.passwords (type, associated_object_id, password) values (''''USER'''', '' || vTable.id || '', '''''' || vTable.passphrase || '''''')'';
        end loop; 
END;
'
 Language 'plpgsql'
 Volatile
 Called On Null Input
 Security invoker;
select tnt_config.copy_user_passwords();
drop function tnt_config.copy_user_passwords();
alter table tnt_config.identity drop column passphrase;

-- create password policy table
drop table if exists tnt_config.password_policy;
create table tnt_config.password_policy (
        id serial primary key,
	name text not null,
	sys_default bool not null default false,
	min_len int not null default -1,
	min_uc_char int not null default -1,
	min_lc_char int not null default -1,
	min_num_char int not null default -1,
	min_spec_char int not null default -1,
	max_char_repeat int not null default -1,
	min_pass_age int not null default -1,
	max_pass_age int not null default -1,
	history_size int not null default -1
) Without Oids;
alter table tnt_config.password_policy owner to impadmin;
grant select on table tnt_config.password_policy to reports;
-- insert policy matching RHEL5 stig
insert into tnt_config.password_policy (name, min_len, min_uc_char, min_lc_char, min_num_char, min_spec_char, max_char_repeat, min_pass_age, max_pass_age, history_size) values ('RHEL5STIG', 14, 1, -1, 1, 1, 3, 1, 60, 5);
