create or replace view lwl_query.display_performance as
select
	pn.name as machine_name,
	png.name as machine_group,
	avg(iq.avg_latency_ms) as avg_latency_ms,
	avg(iq.avg_data_rate_kbps) as avg_data_rate_kbps,
	avg(iq.max_data_rate_kbps) as max_data_rate_kbps,
	avg(iq.total_data_kb) as total_data_kb,
	avg(iq.total_image_data_kb) as total_image_data_kb,
	avg(iq.total_audio_data_kb) as total_audio_data_kb,
	avg(iq.total_usb_data_kb) as total_usb_data_kb
from (
	select

	dp_stats.node_id as node_id,
	avg(case when dp_stats.round_trip_latency_avg_ms > 0 then 
		dp_stats.round_trip_latency_avg_ms else null end) as avg_latency_ms,
	avg(case when (dp_stats.recv_avg_kbit + dp_stats.sent_avg_kbit) > 0 then
		(dp_stats.recv_avg_kbit + dp_stats.sent_avg_kbit) else null end ) AS avg_data_rate_kbps,
	max(dp_stats.recv_max_kbit + dp_stats.sent_max_kbit) AS max_data_rate_kbps,
	sum(dp_stats.recv_total_kbyte + dp_stats.sent_total_kbyte) as total_data_kb,
	sum(dp_stats.recv_total_img_kbyte + dp_stats.sent_total_img_kbyte) as total_image_data_kb,
	sum(dp_stats.recv_total_audio_kbyte + dp_stats.sent_total_audio_kbyte) as total_audio_data_kb,
	sum(dp_stats.recv_total_usb_kbyte + dp_stats.sent_total_usb_kbyte) as total_usb_data_kb

	from

	tnt_audit.summaryreport_display_proto_stats dp_stats

	join tnt_config.policynode pn on (pn.id = dp_stats.node_id)


	group by 

	dp_stats.node_id
) as iq
join tnt_config.policynode pn on (pn.id = iq.node_id)
left outer join tnt_config.nodegroup_node ngn on (ngn.nodeid = iq.node_id)
left outer join tnt_config.policynode png on (png.id = ngn.nodegroupid)

group by pn.name, png.name;

Grant select on lwl_query.display_performance to "query";
