drop view lwl_query.network_app_performance;
alter TABLE tnt_config.interface ALTER COLUMN ip TYPE inet using ip::inet;
REINDEX TABLE tnt_config.interface ;
create or replace view lwl_query.network_app_performance as
select

destapp.name as app_name,
proto.name as protocol_name,
ca.dst_port_icmp_code as protocol_port,

ca.packet_time as packet_time_utc,

(case when usr.id is not null then pi.name else null end) as user_name,
(case when dom.name is not null then dom.name else null end) as user_domain_name,

(case when srcpn.id is not null then srcpn.name else null end) as source_machine,
ca.src_ip as source_ip_addr,

(case when destpn.id is not null then destpn.name else null end) as dest_machine,
ca.dst_ip as dest_ip_addr,

(case when ca.status < 100 then true else false end) as authorized,
(case when (ca.ackstatus and ca.finstatus) then true else false end) as service_level_passed,
(case when ca.fintime = 0 and ca.protocol = 6 then false else true end) as connect_complete,
ca.acktime as network_roundtrip_latency,
ca.fintime as app_response_time,
ca.sentbytes as sent_bytes,
ca.receivebytes as receive_bytes,
ca.sentpackets as sent_packets,
ca.receivepackets as receivepackets

from

tnt_audit.connectattempt ca

left outer join tnt_config.interface destiface on (destiface.ip = ca.dst_ip)

left outer join tnt_config.policynode destpn on (destiface.nodeid = destpn.id)

left outer join tnt_config.node destnde on (destpn.id = destnde.id)

left outer join tnt_config.application destapp on
        ((destapp.defaultprotocol = ca.protocol AND destapp.system_object = false AND
          ((ca.protocol != 1 AND ca.dst_port_icmp_code BETWEEN destapp.defaultportmin AND destapp.defaultportmax) OR
  (ca.protocol = 1 AND ca.src_port_icmp_type = destapp.type AND ca.dst_port_icmp_code = destapp.code))))

left outer join tnt_config.protocol proto on (proto.id = ca.protocol)

left outer join tnt_config.identity usr on ((usr.uid = ca.src_uid))

left outer join tnt_config.policyidentity pi on (pi.id = usr.id)

left outer join tnt_config.domain dom on
  (((pi.domainid = dom.id) and (dom.delete_time is null)))

left outer join
  (select min(iface.nodeid) as nodeid, iface.ip from
   tnt_config.interface iface where iface.delete_time is null group by iface.ip)
   as srciface on (ca.src_sid is null and srciface.ip = ca.src_ip)

left outer join tnt_config.node srcnde on
  (srcnde.sid = ca.src_sid or srciface.nodeid = srcnde.id)

left outer join tnt_config.policynode srcpn on (srcpn.id = srcnde.id)
;
