create extension if not exists dblink;

create or replace function "tnt_audit".text_trend_to_array(baseTable text, columnName text)
returns integer as
'
declare
	partitionCount int;
	rowCount int;
	tmpColumnName text;
	partitionInfo record;
begin
	partitionCount := 0;
	tmpColumnName := columnName || ''_ary'';
	raise debug ''Converting column % in table % to array.  New temp column name: % '', columnName, baseTable, tmpColumnName;
	-- column expected to already exit
	-- execute format(''alter table tnt_audit.%I add %I real[]'', baseTable, tmpColumnName);
	for partitionInfo in select tablename from pg_tables where (schemaname = ''tnt_audit'') and
		(tablename ~ (baseTable || ''_\d+'')) LOOP
		raise debug ''Processing partition: %'', partitionInfo.tablename;
		-- do actual update over dblink.. want each update in own transaction so we dont block things
		perform dblink_connect(''dbname=portal'');
		perform dblink_exec(format(''update tnt_audit.%I set %I = regexp_split_to_array(%I, %L)::smallint[]'', partitionInfo.tableName, tmpColumnName, columnName, '',''));
		perform dblink_disconnect();
		partitionCount := partitionCount + 1;
	end loop;
	raise debug ''% partitions processed, remove old column and renaming tmp'', partitionCount;
	perform format(''alter table tnt_audit.%I drop %I'', baseTable, columnName);
	-- no longer using same column name so no need to rename
	-- execute format(''alter table tnt_audit.%I rename %I to %I'', baseTable, tmpColumnName, columnName);

	return partitionCount;
end;	
'
Language 'plpgsql'
 Volatile
 Called On Null Input
 Security invoker;

create or replace function "tnt_audit".text_trends_to_array(baseTable text)
returns integer as
'
declare
	columnCount int;
	columnInfo record;
begin
	columnCount := 0;
	raise debug ''Converting all text trends on table % to arrays'', baseTable;
	for columnInfo in select column_name from information_schema.columns where table_schema = ''tnt_audit'' and table_name = baseTable and data_type = ''text'' and column_name ~ ''.*trend.*'' LOOP
		raise debug ''Processing column: %'', columnInfo.column_name;
		columnCount := columnCount + 1;
		perform tnt_audit.text_trend_to_array(baseTable, columnInfo.column_name);
	end loop;

	return columnCount;
end;
'
Language 'plpgsql'
 Volatile
 Called On Null Input
 Security invoker;

--select tnt_audit.text_trends_to_array('summaryreports');
--select tnt_audit.text_trends_to_array('summaryreport_partition_stats');
--select tnt_audit.text_trends_to_array('summaryreport_login_stats');
--select tnt_audit.text_trends_to_array('summaryreport_process_stats');
--select tnt_audit.text_trends_to_array('summaryreport_datastore_stats');
--select tnt_audit.text_trends_to_array('summaryreport_nic_stats');
--select tnt_audit.text_trends_to_array('summaryreport_folder_stats');
--select tnt_audit.text_trends_to_array('summaryreport_folder_ext_stats');
--select tnt_audit.text_trends_to_array('summaryreport_ping_stats');
--select tnt_audit.text_trends_to_array('summaryreport_gpu_stats');
--select tnt_audit.text_trends_to_array('summaryreport_display_proto_stats');

drop function tnt_audit.text_trends_to_array(text);
drop function tnt_audit.text_trend_to_array(text, text);
