create or replace function "tnt_audit".add_connectattempt_index(partitionName text, indexSuffix text, indexFields text)
returns void as
'
declare
	newIndexName text;
	indexExists int;
begin
	newIndexName := partitionName || ''_'' || indexSuffix;
	raise debug ''Checking for index % on partition %'', newIndexName, partitionname; 
	select into indexExists count(*) from pg_indexes where indexname = newIndexName and schemaname = ''tnt_audit'' and tablename = partitionName;
	if indexExists = 0 then
		raise debug ''Index does not exist, will create'';
		execute ''create index '' || newIndexName || '' on tnt_audit.'' || partitionName || '' ( '' || indexFields || '' )'';
        else
		raise debug ''Index already exists'';
	end if;
end;	
'
Language 'plpgsql'
 Volatile
 Called On Null Input
 Security invoker;

create or replace function "tnt_audit".add_connectattempt_indexes(partitionName text)
returns void as
'
begin
	raise debug ''Added new indexes to partition: %'', partitionName;
	perform tnt_audit.add_connectattempt_index(partitionName, ''tn'', ''tn'');
	perform tnt_audit.add_connectattempt_index(partitionName, ''tn_station'', ''tn,stationid'');
end;	
'
Language 'plpgsql'
 Volatile
 Called On Null Input
 Security invoker;

create or replace function "tnt_audit".create_connectattempt_indexes()
returns integer as
'
declare
	partitionCount int;
	partitionInfo record;
begin
	partitionCount := 0;
	raise debug ''Adding new indexes to connectattempt partitions'';
	for partitionInfo in select tablename from pg_tables where schemaname = ''tnt_audit'' and tablename like ''connectattempt_%'' LOOP
		raise debug ''Processing partition: %'', partitionInfo.tablename;
		partitionCount := partitionCount + 1;
		perform tnt_audit.add_connectattempt_indexes(partitionInfo.tablename);
	end loop;

	return partitionCount;
end;
'
Language 'plpgsql'
 Volatile
 Called On Null Input
 Security invoker;

select tnt_audit.create_connectattempt_indexes(); 

drop function tnt_audit.create_connectattempt_indexes();
drop function tnt_audit.add_connectattempt_indexes(text);
drop function tnt_audit.add_connectattempt_index(text, text, text);
