create or replace function "tnt_audit".migrate_urls(partitionPrefix text, urlQuery text, urlDetails text, urlIdColumn text)
returns integer as
'
declare
	migratedUrls int;
	addedUrls int;
	partitionPattern text;
	partitionName text;
	urlInfo record;
	urlId int;
	updateQuery text;
begin
	migratedUrls := 0;
	addedUrls := 0;
	partitionPattern := partitionPrefix || ''_%'';
	--raise warning ''Table prefix %, URL query %, details query %'', partitionPattern, urlQuery, urlDetails;
	for partitionName in select tablename from pg_tables where schemaname = ''tnt_audit'' and tablename like partitionPattern loop 
		--raise warning ''Migrating URLs in table: %'', partitionName;
		for urlInfo in execute (''select distinct '' || urlQuery || '' as url, '' || urlDetails 
			|| '' as url_details from tnt_audit.'' || partitionName) loop
			--raise warning ''Found URL: %, details: %'', urlInfo.url, urlInfo.url_details;
			select into urlId id from tnt_audit.urls where url = urlInfo.url;
			if urlId is null then
				--raise warning ''URL % is not in tnt_audit.urls, adding'', urlInfo.url;
				insert into tnt_audit.urls (url, details, times_seen) values (urlInfo.url, urlInfo.url_details, 1);
				addedUrls := addedUrls + 1;
				select into urlId id from tnt_audit.urls where url = urlInfo.url;
			end if;
			updateQuery := format(''update tnt_audit.%s set %s = %L where %s = %L'', partitionName, urlIdColumn, urlId, urlQuery, urlInfo.url);
			--raise warning ''URL has ID %, update query is %'', urlId, updateQuery;
			execute updateQuery;
			migratedUrls := migratedUrls + 1;
		end loop;
	end loop;

	--raise warning ''% urls migrated, % were new'', migratedUrls, addedUrls;

	return migratedUrls;
end;	
'
Language 'plpgsql'
 Volatile
 Called On Null Input
 Security invoker;

-- migrate tab urls then remove old columns
select tnt_audit.migrate_urls('summaryreport_browser_tab_stats', 'details->''uri''', '((case when url_host is not null then (''host=>'' || url_host) else '''' end) || (case when url_path is not null then ('',path=>'' || url_path) else '''' end) || '',proto=>'' || url_proto || (case when url_domain is not null then ('',domain=>'' || url_domain) else '''' end))::hstore', 'url_id');
alter table tnt_audit.summaryreport_browser_tab_stats drop url_proto;
alter table tnt_audit.summaryreport_browser_tab_stats drop url_host;
alter table tnt_audit.summaryreport_browser_tab_stats drop url_domain;
alter table tnt_audit.summaryreport_browser_tab_stats drop url_path;

-- now connecturl
select tnt_audit.migrate_urls('connecturl', 'url', '(''host=>'' || host || '',domain=>'' || domain)::hstore', 'url_id');
alter table tnt_audit.connecturl drop url;
alter table tnt_audit.connecturl drop host; 
alter table tnt_audit.connecturl drop domain; 


drop function tnt_audit.migrate_urls(text, text, text, text);
