/* Create Views */
drop view if exists lwl_query.desktop_app_performance;

create or replace view lwl_query.desktop_app_performance as
select

app.name as app_name,
app.app_version as app_version,
pstats.name as process_name,

pmachine.name as machine_name,
machinegroup.name as machine_group,

pstats.owner_name as user_name,
usergroup.name as user_group,

pstats.start_date as inspect_start_time_utc,
pstats.end_date as inspect_end_time_utc,

avg(pstats.launch_delay_ms)/1000 as launch_delay_s,
avg(case when pstats.non_responsive then 1 else 0 end) as num_non_responsive,

avg(pstats.cpu_avg_sys) as avg_system_cpu_percent,
avg(pstats.cpu_avg_user) as avg_user_cpu_percent,
avg(pstats.mem_avg / 1024) as avg_mem_used_mb,
avg(pstats.pf_avg) as avg_page_faults,
avg(pstats.io_avg) as avg_io,
avg(pstats.graph_avg) as avg_graphics_intensity,

avg(pstats.cpu_peak_sys) as peak_system_cpu_percent,
avg(pstats.cpu_peak_user) as peak_user_cpu_percent,
avg(pstats.mem_peak / 1048576) as peak_mem_used_mb,
avg(pstats.pf_peak) as peak_page_faults,
avg(pstats.io_peak) as peak_io,
avg(pstats.graph_peak) as peak_graphics_intensity

from tnt_audit.summaryreport_process_stats pstats
join tnt_config.desktop_app app on (pstats.desk_app_id = app.id)

join tnt_config.policynode pmachine on (pstats.node_id = pmachine.id)

left outer join tnt_config.nodegroup_node ngroup on (
        (pstats.node_id = ngroup.nodeid)
        )

left outer join tnt_config.policynode machinegroup on (
        (ngroup.nodegroupid = machinegroup.id)
        )

left outer join tnt_config.identitygroup_identity igroup on (
        (pstats.owner_id = igroup.uid)
        )

left outer join tnt_config.policyidentity usergroup on (
        (igroup.groupid = usergroup.id)
        )

group by app_name, app_version, pstats.name, machine_name, machine_group, user_name, user_group, inspect_start_time_utc, inspect_end_time_utc
;

drop view if exists lwl_query.host_performance;

create or replace view lwl_query.host_performance as
select 

vmhost.name as host_name,

hstats.start_date as inspect_start_time_utc,
hstats.end_date as inspect_end_time_utc,

avg(hstats.num_vms) as avg_num_machines,
avg(hstats.avg_cpu_used_percent) as avg_cpu_used_percent,
avg(hstats.avg_vm_ready_time_ms) as avg_cpu_ready_per_vm_ms,
avg(hstats.cpu_limited_percent) as avg_cpu_limited_percent,
avg(hstats.avg_mem_used_percent) as avg_mem_used_percent,
avg(hstats.avg_mem_balloon_kb) / 1024 as avg_mem_balloon_mb,
avg(hstats.avg_swap_used_kb) / 1024 as avg_swap_used_mb,
avg(hstats.avg_swap_used_percent) as avg_swap_used_percent,
avg(hstats.disk_read_iops+disk_write_iops) as avg_disk_iops,
avg(hstats.avg_disk_io_kbps) as avg_disk_io_kb_s,
avg(hstats.avg_disk_latency_ms) as avg_disk_latency_ms,
avg(hstats.avg_net_io_kbps) as avg_net_io_kb_s,

max(hstats.num_vms) as peak_num_machines,
max(hstats.avg_cpu_used_percent) as peak_cpu_used_percent,
max(hstats.avg_vm_ready_time_ms) as peak_cpu_ready_per_vm_ms,
max(hstats.cpu_limited_percent) as peak_cpu_limited_percent,
max(hstats.avg_mem_used_percent) as peak_mem_used_percent,
max(hstats.avg_mem_balloon_kb) / 1024 as peak_mem_balloon_mb,
max(hstats.avg_swap_used_kb) / 1024 as peak_swap_used_mb,
max(hstats.avg_swap_used_percent) as peak_swap_used_percent,
max(hstats.disk_read_iops+disk_write_iops) as peak_disk_iops,
max(hstats.avg_disk_io_kbps) as peak_disk_io_kb_s,
max(hstats.avg_disk_latency_ms) as peak_disk_latency_ms,
max(hstats.avg_net_io_kbps) as peak_net_io_kb_s,

sum(hstats.total_vm_ready_time_ms) as total_cpu_ready_time_ms, 
sum(hstats.total_packets_rx) as total_net_packets_rx,
sum(hstats.total_packets_tx) as total_net_packets_tx

from tnt_audit.hoststats hstats 

join tnt_config.vmhost vmhost on (hstats.vmhost_id = vmhost.id)

group by host_name, inspect_start_time_utc, inspect_end_time_utc
;

drop view if exists lwl_query.machine_configuration;

create or replace view lwl_query.machine_configuration as
select

pmachine.name as machine_name,
machinegroup.name as machine_group,

os.name as os_name,
os.version as os_version,
os.patch_level as os_patch_level,

max(registration_time) as registration_datetime_utc,
age(max(lastcontact)) as time_since_contact_hub,
age(max(bios_date)) as machine_age,
max(last_boot_time) as last_boot_datetime_utc,

count(distinct(cpus.id)) as num_cpus,
avg(cpus.cores) * count(distinct(cpus.id)) as num_cores,
avg(cpus.speed_mhz) * count(distinct(cpus.id)) as cpu_speed_mhz,

max(mstats.mem_alloc) / 1048576 as mem_alloc_mb,
max(mstats.swap_alloc) / 1048576 as swap_alloc_mb,

count(distinct(disk_stats.name)) as num_disks,
(avg(disk_stats.size) / 1024) * count(distinct(disk_stats.name)) as disk_alloc_mb,

count(distinct(displays.id)) as num_displays,

max(hardware.keyboard_type) as keyboard_type,
max(hardware.mouse_type) as mouse_type,
max(hardware.local_printer_count) as num_local_printers,
max(hardware.network_printer_count) as num_network_printers,

count(distinct(devices.id)) as num_external_devices,

count(distinct(nw_stats.name)) as num_nics,
avg(nw_stats.speed) as avg_nic_speed,
max(nw_stats.speed) as max_nic_speed

from tnt_config.node node

join tnt_config.policynode pmachine on (node.id = pmachine.id)
join tnt_config.os os on (node.os_id = os.id)

left outer join tnt_config.nodegroup_node ngroup on (
        (node.id = ngroup.nodeid)
        )

left outer join tnt_config.policynode machinegroup on (
        (ngroup.nodegroupid = machinegroup.id)
        )

left outer join tnt_config.node_hardware hardware on (
        (node.hardware_id = hardware.id)
        )

left outer join tnt_config.node_hardware_cpus cpus on (
        (node.hardware_id = cpus.hardware_id)
        )

left outer join tnt_config.node_hardware_displays displays on (
        (node.hardware_id = displays.hardware_id)
        )

left outer join tnt_config.node_hardware_extdevices devices on (
        (node.hardware_id = devices.hardware_id)
        )

left outer join tnt_audit.summaryreports mstats on (
        (mstats.node_id = node.id) and
        (mstats.end_date = node.last_enddate)
        )

left outer join tnt_audit.summaryreport_nic_stats nw_stats on (
        (nw_stats.node_id = node.id) and
        (nw_stats.end_date = node.last_enddate)
        )

left outer join tnt_audit.summaryreport_partition_stats disk_stats on (
        (disk_stats.node_id = node.id) and
        (disk_stats.end_date = node.last_enddate)
        )

where node.delete_time is null
group by machine_name, machine_group, os_name, os_version, os_patch_level
;

drop view if exists lwl_query.machine_performance;

create or replace view lwl_query.machine_performance as
select

pmachine.name as machine_name,
machinegroup.name as machine_group,

mstats.start_date as inspect_start_time_utc,
mstats.end_date as inspect_end_time_utc,

avg(mstats.vdi_fit_overall) as vdi_fit,
avg(mstats.vdi_ux_overall) as vdi_ux,

count(distinct(log_stats.name)) as num_users,

avg(log_stats.login_delay_ms)/1000 as avg_login_delay_s,
avg(mstats.cpu_avg_sys) as avg_system_cpu_percent,
avg(mstats.cpu_avg_user) as avg_user_cpu_percent,
avg(mstats.cpu_queue_avg) as avg_cpu_queue_len,
avg(mstats.cpu_cswitch_avg) as avg_cpu_context_switch_per_s,
avg(mstats.mem_avg / 1024) as avg_mem_used_mb,
avg(((mstats.mem_avg + mstats.swap_avg) / (mstats.mem_alloc + mstats.swap_alloc + 1)) * 100) as avg_mem_used_percent,
avg(disk_stats.avg_used / 1024) as avg_disk_used_mb,
avg(disk_stats.read_avg + disk_stats.write_avg) as avg_disk_iops,
avg(disk_stats.read_io_avg + disk_stats.write_io_avg) as avg_disk_kb_s,
avg(disk_stats.queue_avg) as avg_disk_queue_len,
avg(nw_stats.receive_rate) as avg_network_kb_s,
avg(mstats.avg_center_nrt / 1000) as avg_latency_to_hub_ms,
avg(mstats.avg_inc_nrt / 1000) as avg_incoming_latency_ms,

max(log_stats.login_delay_ms)/1000 as peak_login_delay_s,
max(mstats.cpu_peak_sys) as peak_system_cpu_percent,
max(mstats.cpu_peak_user) as peak_user_cpu_percent,
max(mstats.cpu_queue_peak) as peak_cpu_queue_len,
max(mstats.cpu_cswitch_peak) as peak_cpu_context_switch_per_s,
max(mstats.mem_peak / 1024) as peak_mem_used_mb,
max(((mstats.mem_peak + mstats.swap_peak) / (mstats.mem_alloc + mstats.swap_alloc + 1)) * 100) as peak_mem_used_percent,
max(disk_stats.peak_used / 1024) as peak_disk_used_mb,
max(disk_stats.read_peak + disk_stats.write_peak) as peak_disk_iops,
max(disk_stats.read_io_peak + disk_stats.write_io_peak) as peak_disk_kb_s,
max(disk_stats.queue_peak) as peak_disk_queue_len,
max(nw_stats.receive_rate) as peak_network_kb_s,
max(mstats.avg_center_nrt / 1000) as peak_latency_to_hub_ms,
max(mstats.avg_inc_nrt / 1000) as peak_incoming_latency_ms

from tnt_audit.summaryreports mstats

join tnt_config.policynode pmachine on (mstats.node_id = pmachine.id)

left outer join tnt_config.nodegroup_node ngroup on (
        (mstats.node_id = ngroup.nodeid)
        )

left outer join tnt_config.policynode machinegroup on (
        (ngroup.nodegroupid = machinegroup.id)
        )

left outer join tnt_audit.summaryreport_login_stats log_stats on (
        (log_stats.node_id = mstats.node_id) and
        (log_stats.start_date = mstats.start_date) and
        (log_stats.end_date = mstats.end_date)
        )

left outer join tnt_audit.summaryreport_nic_stats nw_stats on (
        (nw_stats.node_id = mstats.node_id) and
        (nw_stats.start_date = mstats.start_date) and
        (nw_stats.end_date = mstats.end_date)
        )

left outer join tnt_audit.summaryreport_partition_stats disk_stats on (
        (disk_stats.node_id = mstats.node_id) and
        (disk_stats.start_date = mstats.start_date) and
        (disk_stats.end_date = mstats.end_date)
        )

group by machine_name, machine_group, inspect_start_time_utc, inspect_end_time_utc
;

drop view if exists lwl_query.network_performance_tests;

create or replace view lwl_query.network_performance_tests as
select

pmachine.name as machine_name,
machinegroup.name as machine_group,
ping_stats.address as host_address,

mstats.start_date as inspect_start_time_utc,
mstats.end_date as inspect_end_time_utc,

avg(ping_stats.avg) as avg_network_roundtrip_ms,
max(ping_stats.peak) as peak_network_roundtrip_ms,
avg(ping_stats.packets_sent) as avg_packets_sent,
avg(ping_stats.packets_lost) as avg_packets_lost

from tnt_audit.summaryreports mstats
join tnt_config.policynode pmachine on (mstats.node_id = pmachine.id)
left outer join tnt_config.nodegroup_node ngroup on (
        (mstats.node_id = ngroup.nodeid)
        )

left outer join tnt_config.policynode machinegroup on (
        (ngroup.nodegroupid = machinegroup.id)
        )

left outer join tnt_audit.summaryreport_ping_stats ping_stats on (
        (ping_stats.node_id = mstats.node_id) and
        (ping_stats.start_date = mstats.start_date) and
        (ping_stats.end_date = mstats.end_date)
        )

group by machine_name, machine_group, host_address, inspect_start_time_utc, inspect_end_time_utc
;

drop view if exists lwl_query.desktop_app_inventory;

create or replace view lwl_query.desktop_app_inventory as
select

pmachine.name as machine_name,
machinegroup.name as machine_group,

desk_app.name as app_name,
desk_app.app_version as app_version,
app.install_date as install_date,
app.size / 1024 as install_size_mb,
app.svc_provided as number_services_installed,
app.svc_required as number_services_used,
app.drv_provided as number_drivers_installed,
desk_app.process_names as process_names

from tnt_config.policynode pmachine
left outer join tnt_config.nodegroup_node ngroup on (
        (pmachine.id = ngroup.nodeid)
        )

left outer join tnt_config.policynode machinegroup on (
        (ngroup.nodegroupid = machinegroup.id)
        )

join tnt_config.node_application app on
	(pmachine.id = app.node_id
	)

join tnt_config.desktop_app desk_app on
	(app.desktop_app_id = desk_app.id and not desk_app.is_patch
	)

;

create or replace view lwl_query.desktop_app_inventory as
select

pmachine.name as machine_name,
machinegroup.name as machine_group,

desk_app.name as app_name,
desk_app.app_version as app_version,
app.install_date as install_date,
app.size / 1024 as install_size_mb,
app.svc_provided as number_services_installed,
app.svc_required as number_services_used,
app.drv_provided as number_drivers_installed,
desk_app.process_names as process_names

from tnt_config.policynode pmachine
left outer join tnt_config.nodegroup_node ngroup on (
        (pmachine.id = ngroup.nodeid)
        )

left outer join tnt_config.policynode machinegroup on (
        (ngroup.nodegroupid = machinegroup.id)
        )

join tnt_config.node_application app on
        (pmachine.id = app.node_id
        )

join tnt_config.desktop_app desk_app on
        (app.desktop_app_id = desk_app.id and not desk_app.is_patch
        )

;

create or replace view lwl_query.folder_inventory as
select

pmachine.name as machine_name,
machinegroup.name as machine_group,

log_stats.name as user_name, 
usergroup.name as user_group,

folder_stats.name as folder_name,

mstats.start_date as inspect_start_time_utc,
mstats.end_date as inspect_end_time_utc,

avg(folder_stats.count) as number_of_files,
avg(folder_stats.size) / 1024 as folder_size_mb

from tnt_audit.summaryreports mstats
join tnt_config.policynode pmachine on (mstats.node_id = pmachine.id)
left outer join tnt_config.nodegroup_node ngroup on (
        (mstats.node_id = ngroup.nodeid)
        )

left outer join tnt_config.policynode machinegroup on (
        (ngroup.nodegroupid = machinegroup.id)
        )

left outer join tnt_audit.summaryreport_login_stats log_stats on (
	(log_stats.node_id = mstats.node_id) and
	(log_stats.start_date = mstats.start_date) and
	(log_stats.end_date = mstats.end_date)
	)

left outer join tnt_config.identitygroup_identity igroup on (
	(log_stats.user_id = igroup.uid)
	)

left outer join tnt_config.policyidentity usergroup on (
	(igroup.groupid = usergroup.id)
	)

join tnt_audit.summaryreport_folder_stats folder_stats on (
        (folder_stats.node_id = mstats.node_id) and
        (folder_stats.start_date = mstats.start_date) and
        (folder_stats.end_date = mstats.end_date) and
	(folder_stats.count > 0 and folder_stats.size > 0)
        )

where
mstats.end_date = 
  (select max(f2.end_date) from tnt_audit.summaryreport_folder_stats f2
   where f2.node_id = mstats.node_id)

group by machine_name, machine_group, user_name, user_group, folder_name, inspect_start_time_utc, inspect_end_time_utc
;

create or replace view lwl_query.doc_type_inventory as
select

pmachine.name as machine_name,
machinegroup.name as machine_group,

log_stats.name as user_name, 
usergroup.name as user_group,

folder_stats.folder_name as folder_name,
folder_stats.name as doc_type_extension,

mstats.start_date as inspect_start_time_utc,
mstats.end_date as inspect_end_time_utc,

avg(folder_stats.count) as number_of_files,
avg(folder_stats.size) as size_of_files_kb

from tnt_audit.summaryreports mstats
join tnt_config.policynode pmachine on (mstats.node_id = pmachine.id)
left outer join tnt_config.nodegroup_node ngroup on (
        (mstats.node_id = ngroup.nodeid)
        )

left outer join tnt_config.policynode machinegroup on (
        (ngroup.nodegroupid = machinegroup.id)
        )

left outer join tnt_audit.summaryreport_login_stats log_stats on (
	(log_stats.node_id = mstats.node_id) and
	(log_stats.start_date = mstats.start_date) and
	(log_stats.end_date = mstats.end_date)
	)

left outer join tnt_config.identitygroup_identity igroup on (
	(log_stats.user_id = igroup.uid)
	)

left outer join tnt_config.policyidentity usergroup on (
	(igroup.groupid = usergroup.id)
	)

join tnt_audit.summaryreport_folder_ext_stats folder_stats on (
        (folder_stats.node_id = mstats.node_id) and
        (folder_stats.start_date = mstats.start_date) and
        (folder_stats.end_date = mstats.end_date) and
	(folder_stats.count > 0 and folder_stats.size > 0)
        )

where
mstats.end_date = 
  (select max(f2.end_date) from tnt_audit.summaryreport_folder_ext_stats f2
   where f2.node_id = mstats.node_id)

group by machine_name, machine_group, user_name, user_group, folder_name, doc_type_extension, inspect_start_time_utc, inspect_end_time_utc
;



/* Role permissions on views */
Grant select on lwl_query.desktop_app_performance to "query";
Grant select on lwl_query.host_performance to "query";
Grant select on lwl_query.machine_configuration to "query";
Grant select on lwl_query.machine_performance to "query";
Grant select on lwl_query.network_app_performance to "query";
Grant select on lwl_query.san_performance to "query";
Grant select on lwl_query.user_performance to "query";
Grant select on lwl_query.network_performance_tests to "query";
Grant select on lwl_query.desktop_app_inventory to "query";
Grant select on lwl_query.folder_inventory to "query";
Grant select on lwl_query.doc_type_inventory to "query";
