Create or Replace function "tnt_audit"."fix_time_indexes"(varchar)
Returns int As
'
DECLARE
	table_prefix alias for $1;
	table record;
	count int;
BEGIN
	raise warning ''fixing time indexes in % partitions'', table_prefix;

	count := 0;

	FOR table in select tablename from pg_tables where schemaname = ''tnt_audit'' and tablename like table_prefix || ''_%'' LOOP
		raise warning ''fixing time index in partition %'', table.tablename;
		execute ''drop index if exists tnt_audit.'' || table.tablename || ''_time'';
		execute ''create index '' || table.tablename || ''_end_time on tnt_audit.'' || table.tablename || '' (end_date)'';
		execute ''create index '' || table.tablename || ''_start_time on tnt_audit.'' || table.tablename || '' (start_date)'';
		count := count + 2;
	end loop;

     return count;
END;
'
 Language 'plpgsql'
 Volatile
 Called On Null Input
 Security invoker;


Create or Replace function "tnt_audit"."fix_all_time_indexes"()
Returns int As
'
DECLARE
	total int;
BEGIN
	total := 0;

	total = total + tnt_audit.fix_time_indexes(''summaryreports'');
	total = total + tnt_audit.fix_time_indexes(''summaryreport_process_stats'');
	total = total + tnt_audit.fix_time_indexes(''summaryreport_login_stats'');
	total = total + tnt_audit.fix_time_indexes(''summaryreport_partition_stats'');
	total = total + tnt_audit.fix_time_indexes(''summaryreport_nic_stats'');
	total = total + tnt_audit.fix_time_indexes(''summaryreport_folder_stats'');
	total = total + tnt_audit.fix_time_indexes(''summaryreport_folder_ext_stats'');
	total = total + tnt_audit.fix_time_indexes(''hoststats'');

     return total;
END;
'
 Language 'plpgsql'
 Volatile
 Called On Null Input
 Security invoker;

select tnt_audit.fix_all_time_indexes();

drop function tnt_audit.fix_all_time_indexes();
drop function tnt_audit.fix_time_indexes(varchar);
