alter table tnt_config.desktop_app add last_seen timestamp;
alter table tnt_config.node_application add last_seen timestamp;

Create table "matviews"
(
	"mv_name" Name NOT NULL,
	"v_name" Name NOT NULL,
	"last_refresh" Timestamp,
 primary key ("mv_name")
) Without Oids;

CREATE OR REPLACE FUNCTION create_matview(NAME, NAME)
 RETURNS VOID
 SECURITY DEFINER
 LANGUAGE plpgsql AS '
 DECLARE
     matview ALIAS FOR $1;
     view_name ALIAS FOR $2;
     entry matviews%ROWTYPE;
 BEGIN
     SELECT * INTO entry FROM matviews WHERE mv_name = matview;
 
     IF FOUND THEN
         RAISE EXCEPTION ''Materialized view ''''%'''' already exists.'',
           matview;
     END IF;
 
     EXECUTE ''REVOKE ALL ON '' || view_name || '' FROM PUBLIC''; 
 
     EXECUTE ''GRANT SELECT ON '' || view_name || '' TO PUBLIC'';
 
     EXECUTE ''CREATE TABLE '' || matview || '' AS SELECT * FROM '' || view_name;
 
     EXECUTE ''REVOKE ALL ON '' || matview || '' FROM PUBLIC'';
 
     EXECUTE ''GRANT SELECT ON '' || matview || '' TO PUBLIC'';
 
     INSERT INTO matviews (mv_name, v_name, last_refresh)
       VALUES (matview, view_name, CURRENT_TIMESTAMP); 
     
     RETURN;
 END
 ';

CREATE OR REPLACE FUNCTION drop_matview(NAME) RETURNS VOID
 SECURITY DEFINER
 LANGUAGE plpgsql AS '
 DECLARE
     matview ALIAS FOR $1;
     entry matviews%ROWTYPE;
 BEGIN
 
     SELECT * INTO entry FROM matviews WHERE mv_name = matview;
 
     IF NOT FOUND THEN
         RAISE EXCEPTION ''Materialized view % does not exist.'', matview;
     END IF;
 
     EXECUTE ''DROP TABLE '' || matview;
     DELETE FROM matviews WHERE mv_name=matview;
 
     RETURN;
 END
'
;

CREATE OR REPLACE FUNCTION refresh_matview(name) RETURNS VOID
 SECURITY DEFINER
 LANGUAGE plpgsql AS '
 DECLARE 
     matview ALIAS FOR $1;
     entry matviews%ROWTYPE;
 BEGIN
 
     SELECT * INTO entry FROM matviews WHERE mv_name = matview;
 
     IF NOT FOUND THEN
         RAISE EXCEPTION ''Materialized view % does not exist.'', matview;
    END IF;

    EXECUTE ''DELETE FROM '' || matview;
    EXECUTE ''INSERT INTO '' || matview
        || '' SELECT * FROM '' || entry.v_name;

    UPDATE matviews
        SET last_refresh=CURRENT_TIMESTAMP
        WHERE mv_name=matview;

    RETURN;
END
'
;

drop view tnt_config.desktop_app_instance_details;

create or replace view tnt_config.desktop_app_instance_details_view as
SELECT da.id, da.parent_app_id, da.creation_time, da.name, da.last_seen, da.process_names, da.app_version, da.description, da.version, da.type, da.status, count(DISTINCT na.node_id) AS node_count, avg(na.size) AS avg_size, avg(na.svc_provided) AS avg_svc_provided, avg(na.svc_required) AS avg_svc_required, avg(na.drv_provided) AS avg_drv_provided, min(na.install_date) AS min_install_date, max(na.install_date) AS max_install_date, min(na.minor_version_details) AS minor_version_details,
((da.status & 1) = 1) as is_patch,
((da.status & 2) = 2) as system_app,
((da.status & 4) = 4) as installs_shell_extensions,
((da.status & 8) = 8) as uses_dcom,
((da.status & 16) = 16) as include_for_virtualization
   FROM tnt_config.desktop_app da
   LEFT JOIN tnt_config.node_application na ON da.id = na.desktop_app_id
  GROUP BY da.id, da.creation_time, da.name, da.process_names, da.app_version, da.description, da.version, da.type, da.parent_app_id, da.status, da.last_seen;

-- create materialized view
select create_matview('tnt_config.desktop_app_instance_details', 'tnt_config.desktop_app_instance_details_view');
create unique index desktop_app_instance_app_id on tnt_config.desktop_app_instance_details (id);
create index desktop_app_instance_app_name on tnt_config.desktop_app_instance_details (name);

grant all on tnt_config.desktop_app_instance_details to impadmin;
Grant select on tnt_config.desktop_app_instance_details to "reports"; 

insert into tnt_config.job (starttime, command, active, name, usescron, schedule) values (now(), 'bean:matViewRefreshJob', true, 'Materialized View Refresh - 10 min', false, '0 */10 * * * ?');
insert into tnt_config.jobattribute values ((select max(id) from tnt_config.job), 'ViewsToRefresh', 'tnt_config.desktop_app_instance_details');

insert into tnt_config.job (starttime, command, active, name, usescron, schedule) values (now(), 'bean:matViewRefreshJob', true, 'Materialized View Refresh - 30 min', false, '0 */30 * * * ?');
insert into tnt_config.job (starttime, command, active, name, usescron, schedule) values (now(), 'bean:matViewRefreshJob', true, 'Materialized View Refresh - Hourly', false, '0 0 * * * ?');
insert into tnt_config.job (starttime, command, active, name, usescron, schedule) values (now(), 'bean:matViewRefreshJob', true, 'Materialized View Refresh - Every 2 hours', false, '0 0 */2 * * ?');
insert into tnt_config.job (starttime, command, active, name, usescron, schedule) values (now(), 'bean:matViewRefreshJob', true, 'Materialized View Refresh - Every 6 hours', false, '0 0 */6 * * ?');
insert into tnt_config.job (starttime, command, active, name, usescron, schedule) values (now(), 'bean:matViewRefreshJob', true, 'Materialized View Refresh - Every 12 hours', false, '0 0 */12 * * ?');
insert into tnt_config.job (starttime, command, active, name, usescron, schedule) values (now(), 'bean:matViewRefreshJob', true, 'Materialized View Refresh - Every day', false, '0 0 0 * * ?');
