Create table "tnt_audit"."summaryreports"
(
	"node_id" Integer NOT NULL,
	"start_date" Timestamp NOT NULL,
	"end_date" Timestamp NOT NULL,
	"cpu_peak" Double precision NOT NULL,
	"cpu_avg" Double precision NOT NULL,
	"cpu_total" Double precision NOT NULL,
	"cpu_trend" Text,
	"mem_peak" Double precision NOT NULL,
	"mem_avg" Double precision NOT NULL,
	"mem_alloc" Double precision NOT NULL,
	"mem_trend" Text,
	"swap_peak" Double precision NOT NULL,
	"swap_avg" Double precision NOT NULL,
	"swap_alloc" Double precision NOT NULL,
	"swap_trend" Text,
 primary key ("node_id","start_date","end_date")
) Without Oids;

Create table "tnt_audit"."summaryreport_process_stats"
(
	"node_id" Integer NOT NULL,
	"start_date" Timestamp NOT NULL,
	"end_date" Timestamp NOT NULL,
	"pid" Integer NOT NULL,
	"name" Text NOT NULL,
	"mem_peak" Double precision NOT NULL,
	"mem_avg" Double precision NOT NULL,
	"mem_trend" Text,
	"cpu_avg" Double precision NOT NULL,
	"cpu_peak" Double precision NOT NULL,
	"cpu_total" Double precision NOT NULL,
	"cpu_trend" Text,
	"io_avg" Double precision NOT NULL,
	"io_peak" Double precision NOT NULL,
	"io_trend" Text,
	"pf_avg" Double precision NOT NULL,
	"pf_peak" Double precision NOT NULL,
	"pf_trend" Text,
 primary key ("node_id","start_date","end_date","pid","name")
) Without Oids;

Create table "tnt_audit"."summaryreport_partition_stats"
(
	"node_id" Integer NOT NULL,
	"start_date" Timestamp NOT NULL,
	"end_date" Timestamp NOT NULL,
	"vdisk_id" Integer,
	"vdisk_datastoreid" Integer,
	"vdisk_node_id" Integer,
	"name" Text NOT NULL,
	"read_avg" Double precision NOT NULL,
	"read_peak" Double precision NOT NULL,
	"write_avg" Double precision NOT NULL,
	"write_peak" Double precision NOT NULL,
	"read_io_avg" Double precision NOT NULL,
	"read_io_peak" Double precision NOT NULL,
	"write_io_avg" Double precision NOT NULL,
	"write_io_peak" Double precision NOT NULL,
	"write_io_trend" Text,
	"read_io_trend" Text,
	"size" Double precision NOT NULL,
	"avg_used" Double precision NOT NULL,
	"peak_used" Double precision NOT NULL,
	"disk_id" Integer NOT NULL,
 primary key ("node_id","start_date","end_date","name","disk_id")
) Without Oids;

Create table "tnt_audit"."summaryreport_login_stats"
(
	"node_id" Integer NOT NULL,
	"user_id" Integer,
	"start_date" Timestamp NOT NULL,
	"end_date" Timestamp NOT NULL,
	"name" Text NOT NULL,
	"login_time" Timestamp NOT NULL,
	"login_delay_ms" Integer,
	"logout_time" Timestamp,
 primary key ("node_id","start_date","end_date","name","login_time")
) Without Oids;

Create table "tnt_audit"."summaryreport_datastore_stats"
(
	"datastore_id" Integer NOT NULL,
	"date" Timestamp NOT NULL,
	"node_ids" int[] NOT NULL,
	"num_reads" Double precision NOT NULL,
	"num_writes" Double precision NOT NULL,
	"read_io" Double precision NOT NULL,
	"write_io" Double precision NOT NULL,
	"datastore_size" Double precision NOT NULL,
	"datastore_used" Double precision NOT NULL,
 primary key ("datastore_id","date")
) Without Oids;

Create index "summaryreports_node_idx" on "tnt_audit"."summaryreports" using btree ("node_id");
Create index "summaryreports_startdate_index" on "tnt_audit"."summaryreports" using btree ("start_date");
Create index "summaryreports_pstats_node_date_idx" on "tnt_audit"."summaryreport_process_stats" using btree ("node_id","start_date","end_date");
Create index "summaryreport_pastat_node_time_indx" on "tnt_audit"."summaryreport_partition_stats" using btree ("node_id","start_date","end_date");
Create index "summaryreport_lstats_node_time_index" on "tnt_audit"."summaryreport_login_stats" using btree ("node_id","start_date","end_date");
Create index "dstore_stats_date_idx" on "tnt_audit"."summaryreport_datastore_stats" using btree ("date");

Alter table "tnt_audit"."summaryreports" add  foreign key ("node_id") references "tnt_config"."policynode" ("id") on update restrict on delete restrict;
Alter table "tnt_audit"."summaryreport_login_stats" add  foreign key ("user_id") references "tnt_config"."policyidentity" ("id") on update restrict on delete set null;
Alter table "tnt_audit"."summaryreport_datastore_stats" add  foreign key ("datastore_id") references "tnt_config"."datastore" ("id") on update restrict on delete restrict;
Alter table "tnt_audit"."summaryreport_partition_stats" add  foreign key ("vdisk_id","vdisk_datastoreid","vdisk_node_id") references "tnt_config"."virtualdisk" ("id","datastoreid","nodeid") on delete set null;
Alter table "tnt_audit"."summaryreport_process_stats" add  foreign key ("node_id","start_date","end_date") references "tnt_audit"."summaryreports" ("node_id","start_date","end_date") on update restrict on delete restrict;
Alter table "tnt_audit"."summaryreport_partition_stats" add  foreign key ("node_id","start_date","end_date") references "tnt_audit"."summaryreports" ("node_id","start_date","end_date") on update restrict on delete restrict;
Alter table "tnt_audit"."summaryreport_login_stats" add  foreign key ("node_id","start_date","end_date") references "tnt_audit"."summaryreports" ("node_id","start_date","end_date") on update restrict on delete restrict;

Grant select on "tnt_audit"."summaryreports" to "impadmin";
Grant update on "tnt_audit"."summaryreports" to "impadmin";
Grant delete on "tnt_audit"."summaryreports" to "impadmin";
Grant insert on "tnt_audit"."summaryreports" to "impadmin";
Grant references on "tnt_audit"."summaryreports" to "impadmin";
Grant select on "tnt_audit"."summaryreports" to "reports";
Grant select on "tnt_audit"."summaryreport_process_stats" to "impadmin";
Grant update on "tnt_audit"."summaryreport_process_stats" to "impadmin";
Grant delete on "tnt_audit"."summaryreport_process_stats" to "impadmin";
Grant insert on "tnt_audit"."summaryreport_process_stats" to "impadmin";
Grant references on "tnt_audit"."summaryreport_process_stats" to "impadmin";
Grant select on "tnt_audit"."summaryreport_process_stats" to "reports";
Grant select on "tnt_audit"."summaryreport_partition_stats" to "impadmin";
Grant update on "tnt_audit"."summaryreport_partition_stats" to "impadmin";
Grant delete on "tnt_audit"."summaryreport_partition_stats" to "impadmin";
Grant insert on "tnt_audit"."summaryreport_partition_stats" to "impadmin";
Grant references on "tnt_audit"."summaryreport_partition_stats" to "impadmin";
Grant select on "tnt_audit"."summaryreport_partition_stats" to "reports";
Grant select on "tnt_audit"."summaryreport_login_stats" to "impadmin";
Grant update on "tnt_audit"."summaryreport_login_stats" to "impadmin";
Grant delete on "tnt_audit"."summaryreport_login_stats" to "impadmin";
Grant insert on "tnt_audit"."summaryreport_login_stats" to "impadmin";
Grant references on "tnt_audit"."summaryreport_login_stats" to "impadmin";
Grant select on "tnt_audit"."summaryreport_login_stats" to "reports";
Grant select on "tnt_audit"."summaryreport_datastore_stats" to "impadmin";
Grant update on "tnt_audit"."summaryreport_datastore_stats" to "impadmin";
Grant delete on "tnt_audit"."summaryreport_datastore_stats" to "impadmin";
Grant insert on "tnt_audit"."summaryreport_datastore_stats" to "impadmin";
Grant references on "tnt_audit"."summaryreport_datastore_stats" to "impadmin";
Grant select on "tnt_audit"."summaryreport_datastore_stats" to "reports";

Comment on column "tnt_audit"."summaryreports"."node_id" is 'associated node';
Comment on column "tnt_audit"."summaryreports"."start_date" is 'start time of report';
Comment on column "tnt_audit"."summaryreports"."end_date" is 'end time of report';
Comment on column "tnt_audit"."summaryreports"."cpu_peak" is 'peak cpu usage (percent)';
Comment on column "tnt_audit"."summaryreports"."cpu_avg" is 'average cpu usage (percent)';
Comment on column "tnt_audit"."summaryreports"."cpu_total" is 'total cpu (time ms)';
Comment on column "tnt_audit"."summaryreports"."cpu_trend" is 'cpu trend string';
Comment on column "tnt_audit"."summaryreports"."mem_peak" is 'peak memory (kb)';
Comment on column "tnt_audit"."summaryreports"."mem_avg" is 'average memory (kb)';
Comment on column "tnt_audit"."summaryreports"."mem_alloc" is 'total memory allocated';
Comment on column "tnt_audit"."summaryreports"."mem_trend" is 'memory trend string';
Comment on column "tnt_audit"."summaryreports"."swap_peak" is 'peak swap used (kb)';
Comment on column "tnt_audit"."summaryreports"."swap_avg" is 'average swap used (kb)';
Comment on column "tnt_audit"."summaryreports"."swap_alloc" is 'total swap allocated (kb)';
Comment on column "tnt_audit"."summaryreports"."swap_trend" is 'swap trend string';
Comment on column "tnt_audit"."summaryreport_process_stats"."pid" is 'app id';
Comment on column "tnt_audit"."summaryreport_process_stats"."name" is 'process name';
Comment on column "tnt_audit"."summaryreport_process_stats"."mem_peak" is 'peak memory (kb)';
Comment on column "tnt_audit"."summaryreport_process_stats"."mem_avg" is 'average memory (kb)';
Comment on column "tnt_audit"."summaryreport_process_stats"."mem_trend" is 'memory trend string';
Comment on column "tnt_audit"."summaryreport_process_stats"."cpu_avg" is 'average cpu (percent)';
Comment on column "tnt_audit"."summaryreport_process_stats"."cpu_peak" is 'peak cpu (percent)';
Comment on column "tnt_audit"."summaryreport_process_stats"."cpu_total" is 'total cpu time (ms)';
Comment on column "tnt_audit"."summaryreport_process_stats"."cpu_trend" is 'cpu trend string';
Comment on column "tnt_audit"."summaryreport_process_stats"."io_avg" is 'average io (kb/s)';
Comment on column "tnt_audit"."summaryreport_process_stats"."io_peak" is 'io_peak (kb/s)';
Comment on column "tnt_audit"."summaryreport_process_stats"."io_trend" is 'io trend string';
Comment on column "tnt_audit"."summaryreport_process_stats"."pf_avg" is 'average # page faults';
Comment on column "tnt_audit"."summaryreport_process_stats"."pf_peak" is 'peak # page faults';
Comment on column "tnt_audit"."summaryreport_process_stats"."pf_trend" is 'page fault trend string';
Comment on column "tnt_audit"."summaryreport_partition_stats"."node_id" is 'node_id from summaryreports';
Comment on column "tnt_audit"."summaryreport_partition_stats"."start_date" is 'start_date from summaryreports';
Comment on column "tnt_audit"."summaryreport_partition_stats"."end_date" is 'end_date from summaryreports';
Comment on column "tnt_audit"."summaryreport_partition_stats"."vdisk_id" is 'virtualdisk id';
Comment on column "tnt_audit"."summaryreport_partition_stats"."vdisk_datastoreid" is 'virtualdisk datastore id';
Comment on column "tnt_audit"."summaryreport_partition_stats"."vdisk_node_id" is 'column added automatically by toad as it''s part of the key in virtualdisk.  As we already have a node_id column, this will always be null';
Comment on column "tnt_audit"."summaryreport_partition_stats"."read_avg" is 'average read count';
Comment on column "tnt_audit"."summaryreport_partition_stats"."read_peak" is 'peak read count';
Comment on column "tnt_audit"."summaryreport_partition_stats"."write_avg" is 'average write count';
Comment on column "tnt_audit"."summaryreport_partition_stats"."write_peak" is 'peak write count';
Comment on column "tnt_audit"."summaryreport_partition_stats"."read_io_avg" is 'average read io';
Comment on column "tnt_audit"."summaryreport_partition_stats"."read_io_peak" is 'peak read io';
Comment on column "tnt_audit"."summaryreport_partition_stats"."write_io_avg" is 'average write io';
Comment on column "tnt_audit"."summaryreport_partition_stats"."write_io_peak" is 'peak write io';
Comment on column "tnt_audit"."summaryreport_partition_stats"."write_io_trend" is 'write io trend string';
Comment on column "tnt_audit"."summaryreport_partition_stats"."read_io_trend" is 'read io trend string';
Comment on column "tnt_audit"."summaryreport_partition_stats"."size" is 'partition size';
Comment on column "tnt_audit"."summaryreport_partition_stats"."avg_used" is 'average size used (kb)';
Comment on column "tnt_audit"."summaryreport_partition_stats"."peak_used" is 'peak size used (kb)';
Comment on column "tnt_audit"."summaryreport_partition_stats"."disk_id" is 'disk id - maintained separately from virtual disk as the stats might be associated with a node that doesn''t have any virtual disks';
Comment on column "tnt_audit"."summaryreport_datastore_stats"."datastore_id" is 'datastore id';
Comment on column "tnt_audit"."summaryreport_datastore_stats"."date" is 'rollup date';
Comment on column "tnt_audit"."summaryreport_datastore_stats"."node_ids" is 'comma-separated list of nodes that had stats for this datastore and hour';
Comment on column "tnt_audit"."summaryreport_datastore_stats"."num_reads" is '# reads for hour';
Comment on column "tnt_audit"."summaryreport_datastore_stats"."num_writes" is '# writes for hour';
Comment on column "tnt_audit"."summaryreport_datastore_stats"."read_io" is 'read io for hour (kb/s)';
Comment on column "tnt_audit"."summaryreport_datastore_stats"."write_io" is 'write io for hour (kb/s)';
Comment on column "tnt_audit"."summaryreport_datastore_stats"."datastore_size" is 'size of datastore at this hour';
Comment on column "tnt_audit"."summaryreport_datastore_stats"."datastore_used" is 'datasize used size as this hour';

