create or replace view lwl_query.desktop_app_performance as
select 

app.name as app_name, 
app.versions as app_version,
app.process_name as process_name,

pmachine.name as machine_name, 
machinegroup.name as machine_group,

pstats.owner_name as user_name,
usergroup.name as user_group,

pstats.start_date as inspect_start_time_utc,
pstats.end_date as inspect_end_time_utc,

avg(pstats.launch_delay_ms)/1000 as launch_delay_s,
avg(case when pstats.non_responsive then 1 else 0 end) as num_non_responsive,
 
avg(pstats.cpu_avg_sys) as avg_system_cpu_percent, 
avg(pstats.cpu_avg_user) as avg_user_cpu_percent, 
avg(pstats.mem_avg / 1048576) as avg_mem_used_mb, 
avg(pstats.pf_avg) as avg_page_faults,
avg(pstats.io_avg) as avg_io, 
avg(pstats.graph_avg) as avg_graphics_intensity,

avg(pstats.cpu_peak_sys) as peak_system_cpu_percent, 
avg(pstats.cpu_peak_user) as peak_user_cpu_percent, 
avg(pstats.mem_peak / 1048576) as peak_mem_used_mb, 
avg(pstats.pf_peak) as peak_page_faults,
avg(pstats.io_peak) as peak_io, 
avg(pstats.graph_peak) as peak_graphics_intensity

from tnt_audit.summaryreport_process_stats pstats 

join tnt_config.desktop_app app on (pstats.desk_app_id = app.id)

join tnt_config.policynode pmachine on (pstats.node_id = pmachine.id) 

left outer join tnt_config.nodegroup_node ngroup on (
	(pstats.node_id = ngroup.nodeid)
	)

left outer join tnt_config.policynode machinegroup on (
	(ngroup.nodegroupid = machinegroup.id)
	)

left outer join tnt_config.identitygroup_identity igroup on (
	(pstats.owner_id = igroup.uid)
	)

left outer join tnt_config.policyidentity usergroup on (
	(igroup.groupid = usergroup.id)
	)

group by app_name, app_version, process_name, machine_name, machine_group, user_name, user_group, inspect_start_time_utc, inspect_end_time_utc
;


create or replace view lwl_query.host_performance as
select 

vmhost.name as host_name,

hstats.start_date as inspect_start_time_utc,
hstats.end_date as inspect_end_time_utc,

avg(hstats.num_vms) as avg_num_machines,

avg(hstats.avg_cpu_used_percent) as avg_cpu_used_percent,
avg(hstats.avg_vm_ready_time_ms) as avg_cpu_ready_per_vm_ms,
sum(hstats.total_vm_ready_time_ms) as total_cpu_ready_time_ms, 
avg(hstats.avg_mem_used_percent) as avg_mem_used_percent,
avg(hstats.avg_disk_io_kbps) as avg_disk_io_kb_s,
avg(hstats.avg_disk_latency_ms) as avg_disk_latency_ms,
avg(hstats.avg_net_io_kbps) as avg_net_io_kb_s,
sum(hstats.total_packets_rx) as total_net_packets_rx,
sum(hstats.total_packets_tx) as total_net_packets_tx

from tnt_audit.hoststats hstats 

join tnt_config.vmhost vmhost on (hstats.vmhost_id = vmhost.id)

group by host_name, inspect_start_time_utc, inspect_end_time_utc
;

create or replace view lwl_query.machine_configuration as
select 

pmachine.name as machine_name, 
machinegroup.name as machine_group,

os.name as os_name,
os.version as os_version,
os.patch_level as os_patch_level,

max(registration_time) as registration_datetime_utc,
age(max(lastcontact)) as time_since_contact_hub,
age(max(bios_date)) as machine_age,
max(last_boot_time) as last_boot_datetime_utc,

count(distinct(cpus.id)) as num_cpus,
avg(cpus.cores) * count(distinct(cpus.id)) as num_cores,
avg(cpus.speed_mhz) * count(distinct(cpus.id)) as cpu_speed_mhz,

max(mstats.mem_alloc) / 1048576 as mem_alloc_mb,
max(mstats.swap_alloc) / 1048576 as swap_alloc_mb,

count(distinct(disk_stats.name)) as num_disks,
(avg(disk_stats.size) / 1024) * count(distinct(disk_stats.name)) as disk_alloc_mb,

count(distinct(displays.id)) as num_displays,

max(hardware.keyboard_type) as keyboard_type,
max(hardware.mouse_type) as mouse_type,
max(hardware.local_printer_count) as num_local_printers,
max(hardware.network_printer_count) as num_network_printers,

count(distinct(devices.id)) as num_external_devices,

count(distinct(nw_stats.name)) as num_nics,
avg(nw_stats.speed) as avg_nic_speed,
max(nw_stats.speed) as max_nic_speed

from tnt_config.node node

join tnt_config.policynode pmachine on (node.id = pmachine.id) 

join tnt_config.os os on (node.os_id = os.id)

left outer join tnt_config.nodegroup_node ngroup on (
	(node.id = ngroup.nodeid)
	)

left outer join tnt_config.policynode machinegroup on (
	(ngroup.nodegroupid = machinegroup.id)
	)

left outer join tnt_config.node_hardware hardware on (
	(node.hardware_id = hardware.id)
	)

left outer join tnt_config.node_hardware_cpus cpus on (
	(node.hardware_id = cpus.hardware_id)
	)

left outer join tnt_config.node_hardware_displays displays on (
	(node.hardware_id = displays.hardware_id)
	)

left outer join tnt_config.node_hardware_extdevices devices on (
	(node.hardware_id = devices.hardware_id)
	)

left outer join tnt_audit.summaryreports mstats on (
	(mstats.node_id = node.id) and
	(mstats.end_date = node.last_enddate)
	)

left outer join tnt_audit.summaryreport_nic_stats nw_stats on (
	(nw_stats.node_id = node.id) and
	(nw_stats.end_date = node.last_enddate)
	)

left outer join tnt_audit.summaryreport_partition_stats disk_stats on (
	(disk_stats.node_id = node.id) and
	(disk_stats.end_date = node.last_enddate)
	)

where node.delete_time is null

group by machine_name, machine_group, os_name, os_version, os_patch_level
;

create or replace view lwl_query.machine_performance as
select 

pmachine.name as machine_name, 
machinegroup.name as machine_group,

mstats.start_date as inspect_start_time_utc,
mstats.end_date as inspect_end_time_utc,

avg(mstats.vdi_fit_overall) as vdi_fit,
avg(mstats.vdi_ux_overall) as vdi_ux,

count(distinct(log_stats.name)) as num_users, 

avg(log_stats.login_delay_ms)/1000 as avg_login_delay_s, 
avg(mstats.cpu_avg_sys) as avg_system_cpu_percent, 
avg(mstats.cpu_avg_user) as avg_user_cpu_percent, 
avg(mstats.cpu_queue_avg) as avg_cpu_queue_len,
avg(mstats.cpu_cswitch_avg) as avg_cpu_context_switch_per_s,
avg(mstats.mem_avg / 1048576) as avg_mem_used_mb, 
avg(((mstats.mem_avg + mstats.swap_avg) / (mstats.mem_alloc + mstats.swap_alloc + 1)) * 100) as avg_mem_used_percent,
avg(disk_stats.avg_used / 1048576) as avg_disk_used_mb, 
avg(disk_stats.read_avg + disk_stats.write_avg) as avg_disk_iops,
avg(disk_stats.read_io_avg + disk_stats.write_io_avg) as avg_disk_kb_s,
avg(disk_stats.queue_avg) as avg_disk_queue_len,
avg(nw_stats.receive_rate) as avg_network_kb_s, 
avg(mstats.avg_center_nrt) as avg_latency_to_hub_ms,
avg(mstats.avg_inc_nrt) as avg_incoming_latency_ms,

max(log_stats.login_delay_ms)/1000 as peak_login_delay_s, 
max(mstats.cpu_peak_sys) as peak_system_cpu_percent, 
max(mstats.cpu_peak_user) as peak_user_cpu_percent, 
max(mstats.cpu_queue_peak) as peak_cpu_queue_len,
max(mstats.cpu_cswitch_peak) as peak_cpu_context_switch_per_s,
max(mstats.mem_peak / 1048576) as peak_mem_used_mb, 
max(((mstats.mem_peak + mstats.swap_peak) / (mstats.mem_alloc + mstats.swap_alloc + 1)) * 100) as peak_mem_used_percent,
max(disk_stats.peak_used / 1048576) as peak_disk_used_mb, 
max(disk_stats.read_peak + disk_stats.write_peak) as peak_disk_iops,
max(disk_stats.read_io_peak + disk_stats.write_io_peak) as peak_disk_kb_s,
max(disk_stats.queue_peak) as peak_disk_queue_len,
max(nw_stats.receive_rate) as peak_network_kb_s, 
max(mstats.avg_center_nrt) as peak_latency_to_hub_ms,
max(mstats.avg_inc_nrt) as peak_incoming_latency_ms

from tnt_audit.summaryreports mstats 

join tnt_config.policynode pmachine on (mstats.node_id = pmachine.id) 

left outer join tnt_config.nodegroup_node ngroup on (
	(mstats.node_id = ngroup.nodeid)
	)

left outer join tnt_config.policynode machinegroup on (
	(ngroup.nodegroupid = machinegroup.id)
	)

left outer join tnt_audit.summaryreport_login_stats log_stats on (
	(log_stats.node_id = mstats.node_id) and
	(log_stats.start_date = mstats.start_date) and
	(log_stats.end_date = mstats.end_date)
	)

left outer join tnt_audit.summaryreport_nic_stats nw_stats on (
	(nw_stats.node_id = mstats.node_id) and
	(nw_stats.start_date = mstats.start_date) and
	(nw_stats.end_date = mstats.end_date)
	)

left outer join tnt_audit.summaryreport_partition_stats disk_stats on (
	(disk_stats.node_id = mstats.node_id) and
	(disk_stats.start_date = mstats.start_date) and
	(disk_stats.end_date = mstats.end_date)
	)

group by machine_name, machine_group, inspect_start_time_utc, inspect_end_time_utc
;

create or replace view lwl_query.network_app_performance as
select

destapp.name as app_name, 
proto.name as protocol_name,
ca.dst_port_icmp_code as protocol_port,

ca.packet_time as packet_time_utc, 

(case when usr.id is not null then pi.name else null end) as user_name, 
(case when dom.name is not null then dom.name else null end) as user_domain_name, 

(case when srcpn.id is not null then srcpn.name else null end) as source_machine,
ca.src_ip as source_ip_addr, 

(case when destpn.id is not null then destpn.name else null end) as dest_machine,
ca.dst_ip as dest_ip_addr, 

(case when ca.status < 100 then true else false end) as authorized, 
(case when (ca.ackstatus and ca.finstatus) then true else false end) as service_level_passed,
(case when ca.fintime = 0 and ca.protocol = 6 then false else true end) as connect_complete,
ca.acktime as network_roundtrip_latency, 
ca.fintime as app_response_time, 
ca.sentbytes as sent_bytes,
ca.receivebytes as receive_bytes,
ca.sentpackets as sent_packets,
ca.receivepackets as receivepackets

from
	
tnt_audit.connectattempt ca 
	
left outer join tnt_config.interface destiface on (destiface.ip::inet = ca.dst_ip) 
	
left outer join tnt_config.policynode destpn on (destiface.nodeid = destpn.id) 
	
left outer join tnt_config.node destnde on (destpn.id = destnde.id) 

left outer join tnt_config.application destapp on 
	((destapp.defaultprotocol = ca.protocol AND destapp.system_object = false AND 
	  ((ca.protocol != 1 AND ca.dst_port_icmp_code BETWEEN destapp.defaultportmin AND destapp.defaultportmax) OR 
	   (ca.protocol = 1 AND ca.src_port_icmp_type = destapp.type AND ca.dst_port_icmp_code = destapp.code))))
	
left outer join tnt_config.protocol proto on (proto.id = ca.protocol) 

left outer join tnt_config.identity usr on ((usr.uid = ca.src_uid)) 

left outer join tnt_config.policyidentity pi on (pi.id = usr.id) 

left outer join tnt_config.domain dom on 
  (((pi.domainid = dom.id) and (dom.delete_time is null))) 

left outer join 
  (select min(iface.nodeid) as nodeid, iface.ip from 
   tnt_config.interface iface where iface.delete_time is null group by iface.ip) 
   as srciface on (ca.src_sid is null and srciface.ip::inet = ca.src_ip) 

left outer join tnt_config.node srcnde on 
  (srcnde.sid = ca.src_sid or srciface.nodeid = srcnde.id) 

left outer join tnt_config.policynode srcpn on (srcpn.id = srcnde.id) 
;

create or replace view lwl_query.san_performance as
select 

dstore.name as san_name,
dstore.disk_names as san_location,
vmhost.name as host_name,
pn.name as vm_name,

mstats.start_date as inspect_start_time_utc,
mstats.end_date as inspect_end_time_utc,

avg(dstats.read_avg) as avg_read_iops,
avg(dstats.write_avg) as avg_write_iops,
avg(dstats.read_io_avg) as avg_read_kb_s,
avg(dstats.write_io_avg) as avg_write_kb_s,
avg(dstats.queue_avg) as avg_queue_length,

max(dstats.read_peak) as peak_read_iops,
max(dstats.write_peak) as peak_write_iops,
max(dstats.read_io_peak) as peak_read_kb_s,
max(dstats.write_io_peak) as peak_write_kb_s,
max(dstats.queue_peak) as peak_queue_length 

from tnt_audit.summaryreports mstats 

join tnt_config.policynode pn on (mstats.node_id = pn.id) 

join tnt_config.node nd on (mstats.node_id = nd.id)

join tnt_config.vmhost vmhost on (nd.vmhost_id = vmhost.id)

join tnt_audit.summaryreport_partition_stats dstats on
  (mstats.node_id = dstats.node_id and
   mstats.start_date = dstats.start_date and
   mstats.end_date = dstats.end_date)

join tnt_config.datastore dstore on (dstats.vdisk_datastoreid = dstore.id)

group by san_name, san_location, host_name, vm_name, inspect_start_time_utc, inspect_end_time_utc
;

create or replace view lwl_query.user_performance as
select 

log_stats.name as user_name, 
usergroup.name as user_group,

mstats.start_date as inspect_start_time_utc,
mstats.end_date as inspect_end_time_utc,

avg(mstats.vdi_fit_overall) as vdi_fit,
avg(mstats.vdi_ux_overall) as vdi_ux,

count(distinct(pmachine.name)) as desktops_used, 

avg(log_stats.login_delay_ms)*1000 as avg_login_delay_s, 
avg(mstats.cpu_avg_sys) as avg_system_cpu_percent, 
avg(mstats.cpu_avg_user) as avg_user_cpu_percent, 
avg(mstats.cpu_queue_avg) as avg_cpu_queue_len,
avg(mstats.cpu_cswitch_avg) as avg_cpu_context_switch_per_s,
avg(mstats.mem_avg / 1048576) as avg_mem_used_mb, 
avg(((mstats.mem_avg + mstats.swap_avg) / (mstats.mem_alloc + mstats.swap_alloc + 1)) * 100) as avg_mem_used_percent,
avg(disk_stats.avg_used / 1048576) as avg_disk_used_mb, 
avg(disk_stats.read_avg + disk_stats.write_avg) as avg_disk_iops,
avg(disk_stats.read_io_avg + disk_stats.write_io_avg) as avg_disk_kb_s,
avg(disk_stats.queue_avg) as avg_disk_queue_len,
avg(nw_stats.receive_rate) as avg_network_kb_s, 
avg(mstats.avg_center_nrt) as avg_latency_to_hub_ms,
avg(mstats.avg_inc_nrt) as avg_incoming_latency_ms,

max(log_stats.login_delay_ms)*1000 as peak_login_delay_s, 
max(mstats.cpu_peak_sys) as peak_system_cpu_percent, 
max(mstats.cpu_peak_user) as peak_user_cpu_percent, 
max(mstats.cpu_queue_peak) as peak_cpu_queue_len,
max(mstats.cpu_cswitch_peak) as peak_cpu_context_switch_per_s,
max(mstats.mem_peak / 1048576) as peak_mem_used_mb, 
max(((mstats.mem_peak + mstats.swap_peak) / (mstats.mem_alloc + mstats.swap_alloc + 1)) * 100) as peak_mem_used_percent,
max(disk_stats.peak_used / 1048576) as peak_disk_used_mb, 
max(disk_stats.read_peak + disk_stats.write_peak) as peak_disk_iops,
max(disk_stats.read_io_peak + disk_stats.write_io_peak) as peak_disk_kb_s,
max(disk_stats.queue_peak) as peak_disk_queue_len,
max(nw_stats.receive_rate) as peak_network_kb_s, 
max(mstats.avg_center_nrt) as peak_latency_to_hub_ms,
max(mstats.avg_inc_nrt) as peak_incoming_latency_ms

from tnt_audit.summaryreports mstats 

join tnt_config.policynode pmachine on (mstats.node_id = pmachine.id) 

join tnt_config.node nd on (mstats.node_id = nd.id)

join tnt_audit.summaryreport_login_stats log_stats on (
	(log_stats.node_id = mstats.node_id) and
	(log_stats.start_date = mstats.start_date) and
	(log_stats.end_date = mstats.end_date)
	)

left outer join tnt_config.identitygroup_identity igroup on (
	(log_stats.user_id = igroup.uid)
	)

left outer join tnt_config.policyidentity usergroup on (
	(igroup.groupid = usergroup.id)
	)

left outer join tnt_audit.summaryreport_nic_stats nw_stats on (
	(nw_stats.node_id = mstats.node_id) and
	(nw_stats.start_date = mstats.start_date) and
	(nw_stats.end_date = mstats.end_date)
	)

left outer join tnt_audit.summaryreport_partition_stats disk_stats on (
	(disk_stats.node_id = mstats.node_id) and
	(disk_stats.start_date = mstats.start_date) and
	(disk_stats.end_date = mstats.end_date)
	)

group by user_name, user_group, inspect_start_time_utc, inspect_end_time_utc
;
