create or replace view lwl_query.machine_performance as
select

pmachine.name as machine_name,
machinegroup.name as machine_group,

mstats.start_date as inspect_start_time_utc,
mstats.end_date as inspect_end_time_utc,

avg(mstats.vdi_fit_overall) as vdi_fit,
avg(mstats.vdi_ux_overall) as vdi_ux,

count(distinct(log_stats.name)) as num_users,

avg(log_stats.login_delay_ms)/1000 as avg_login_delay_s,
avg(mstats.cpu_avg_sys) as avg_system_cpu_percent,
avg(mstats.cpu_avg_user) as avg_user_cpu_percent,
avg(mstats.cpu_queue_avg) as avg_cpu_queue_len,
avg(mstats.cpu_cswitch_avg) as avg_cpu_context_switch_per_s,
avg(mstats.mem_avg / 1048576) as avg_mem_used_mb,
avg(((mstats.mem_avg + mstats.swap_avg) / (mstats.mem_alloc + mstats.swap_alloc + 1)) * 100) as avg_mem_used_percent,
avg(disk_stats.avg_used / 1048576) as avg_disk_used_mb,
avg(disk_stats.read_avg + disk_stats.write_avg) as avg_disk_iops,
avg(disk_stats.read_io_avg + disk_stats.write_io_avg) as avg_disk_kb_s,
avg(disk_stats.queue_avg) as avg_disk_queue_len,
avg(nw_stats.receive_rate) as avg_network_kb_s,
avg(mstats.avg_center_nrt) as avg_latency_to_hub_ms,
avg(mstats.avg_inc_nrt) as avg_incoming_latency_ms,

max(log_stats.login_delay_ms)/1000 as peak_login_delay_s,
max(mstats.cpu_peak_sys) as peak_system_cpu_percent,
max(mstats.cpu_peak_user) as peak_user_cpu_percent,
max(mstats.cpu_queue_peak) as peak_cpu_queue_len,
max(mstats.cpu_cswitch_peak) as peak_cpu_context_switch_per_s,
max(mstats.mem_peak / 1048576) as peak_mem_used_mb,
max(((mstats.mem_peak + mstats.swap_peak) / (mstats.mem_alloc + mstats.swap_alloc + 1)) * 100) as peak_mem_used_percent,
max(disk_stats.peak_used / 1048576) as peak_disk_used_mb,
max(disk_stats.read_peak + disk_stats.write_peak) as peak_disk_iops,
max(disk_stats.read_io_peak + disk_stats.write_io_peak) as peak_disk_kb_s,
max(disk_stats.queue_peak) as peak_disk_queue_len,
max(nw_stats.receive_rate) as peak_network_kb_s,
max(mstats.avg_center_nrt) as peak_latency_to_hub_ms,
max(mstats.avg_inc_nrt) as peak_incoming_latency_ms

from tnt_audit.summaryreports mstats

join tnt_config.policynode pmachine on (mstats.node_id = pmachine.id)

left outer join tnt_config.nodegroup_node ngroup on (
        (mstats.node_id = ngroup.nodeid)
        )

left outer join tnt_config.policynode machinegroup on (
        (ngroup.nodegroupid = machinegroup.id)
        )

left outer join tnt_audit.summaryreport_login_stats log_stats on (
        (log_stats.node_id = mstats.node_id) and
        (log_stats.start_date = mstats.start_date) and
        (log_stats.end_date = mstats.end_date)
        )

left outer join tnt_audit.summaryreport_nic_stats nw_stats on (
        (nw_stats.node_id = mstats.node_id) and
        (nw_stats.start_date = mstats.start_date) and
        (nw_stats.end_date = mstats.end_date)
        )

left outer join tnt_audit.summaryreport_partition_stats disk_stats on (
        (disk_stats.node_id = mstats.node_id) and
        (disk_stats.start_date = mstats.start_date) and
        (disk_stats.end_date = mstats.end_date)
        )

group by machine_name, machine_group, inspect_start_time_utc, inspect_end_time_utc
;

create or replace view lwl_query.user_performance as
select

log_stats.name as user_name,
usergroup.name as user_group,

mstats.start_date as inspect_start_time_utc,
mstats.end_date as inspect_end_time_utc,

avg(mstats.vdi_fit_overall) as vdi_fit,
avg(mstats.vdi_ux_overall) as vdi_ux,

count(distinct(pmachine.name)) as desktops_used,

avg(log_stats.login_delay_ms)/1000 as avg_login_delay_s,
avg(mstats.cpu_avg_sys) as avg_system_cpu_percent,
avg(mstats.cpu_avg_user) as avg_user_cpu_percent,
avg(mstats.cpu_queue_avg) as avg_cpu_queue_len,
avg(mstats.cpu_cswitch_avg) as avg_cpu_context_switch_per_s,
avg(mstats.mem_avg / 1048576) as avg_mem_used_mb,
avg(((mstats.mem_avg + mstats.swap_avg) / (mstats.mem_alloc + mstats.swap_alloc + 1)) * 100) as avg_mem_used_percent,
avg(disk_stats.avg_used / 1048576) as avg_disk_used_mb,
avg(disk_stats.read_avg + disk_stats.write_avg) as avg_disk_iops,
avg(disk_stats.read_io_avg + disk_stats.write_io_avg) as avg_disk_kb_s,
avg(disk_stats.queue_avg) as avg_disk_queue_len,
avg(nw_stats.receive_rate) as avg_network_kb_s,
avg(mstats.avg_center_nrt) as avg_latency_to_hub_ms,
avg(mstats.avg_inc_nrt) as avg_incoming_latency_ms,

max(log_stats.login_delay_ms)/1000 as peak_login_delay_s,
max(mstats.cpu_peak_sys) as peak_system_cpu_percent,
max(mstats.cpu_peak_user) as peak_user_cpu_percent,
max(mstats.cpu_queue_peak) as peak_cpu_queue_len,
max(mstats.cpu_cswitch_peak) as peak_cpu_context_switch_per_s,
max(mstats.mem_peak / 1048576) as peak_mem_used_mb,
max(((mstats.mem_peak + mstats.swap_peak) / (mstats.mem_alloc + mstats.swap_alloc + 1)) * 100) as peak_mem_used_percent,
max(disk_stats.peak_used / 1048576) as peak_disk_used_mb,
max(disk_stats.read_peak + disk_stats.write_peak) as peak_disk_iops,
max(disk_stats.read_io_peak + disk_stats.write_io_peak) as peak_disk_kb_s,
max(disk_stats.queue_peak) as peak_disk_queue_len,
max(nw_stats.receive_rate) as peak_network_kb_s,
max(mstats.avg_center_nrt) as peak_latency_to_hub_ms,
max(mstats.avg_inc_nrt) as peak_incoming_latency_ms

from tnt_audit.summaryreports mstats

join tnt_config.policynode pmachine on (mstats.node_id = pmachine.id)

join tnt_config.node nd on (mstats.node_id = nd.id)

join tnt_audit.summaryreport_login_stats log_stats on (
        (log_stats.node_id = mstats.node_id) and
        (log_stats.start_date = mstats.start_date) and
        (log_stats.end_date = mstats.end_date)
        )

left outer join tnt_config.identitygroup_identity igroup on (
        (log_stats.user_id = igroup.uid)
        )

left outer join tnt_config.policyidentity usergroup on (
        (igroup.groupid = usergroup.id)
        )

left outer join tnt_audit.summaryreport_nic_stats nw_stats on (
        (nw_stats.node_id = mstats.node_id) and
        (nw_stats.start_date = mstats.start_date) and
        (nw_stats.end_date = mstats.end_date)
        )

left outer join tnt_audit.summaryreport_partition_stats disk_stats on (
        (disk_stats.node_id = mstats.node_id) and
        (disk_stats.start_date = mstats.start_date) and
        (disk_stats.end_date = mstats.end_date)
        )

group by user_name, user_group, inspect_start_time_utc, inspect_end_time_utc
;

Grant select on lwl_query.machine_performance to "query";
Grant select on lwl_query.user_performance to "query";
