-- drop old index
drop index tnt_config.name_process_name_type_idx;

-- create new columns
alter table tnt_config.desktop_app add process_names text;
alter table tnt_config.desktop_app add app_version text;

-- copy data
-- 1 - we need to split up apps with multiple versions into multiple rows
create or replace function tnt_config.desktop_app_split_versions()
returns int as
'
declare
        app_details record;
        split_count int;
        versions_array text[];
        cur_version text;
        version_index int;
begin
        split_count := 0;

        FOR app_details in select * from tnt_config.desktop_app LOOP
                raise notice ''Checking desktop app % for multiple versions'', app_details.name;
                if (strpos(app_details.versions, ''!'') > 0) then
                        version_index := 0;
                        raise warning ''App % has multiple versions'', app_details.name;
                        select into versions_array regexp_split_to_array(app_details.versions, ''!'');
                        for cur_version in select tnt_audit.unnest(versions_array) LOOP
                                raise warning ''Process version %, index: %'', cur_version, version_index;
                                if (version_index = 0) then
                                        raise warning ''Updating original record with version: %'', cur_version;
                                        update tnt_config.desktop_app set versions = cur_version, app_version = cur_version where id = app_details.id;
                                else
                                        raise warning ''Creating new record with version: %'', cur_version;
                                        insert into tnt_config.desktop_app (creation_time, name, process_name, versions, description, type, app_version) values(current_timestamp, app_details.name, app_details.process_name, cur_version, app_details.description, app_details.type, cur_version);
                                end if;
                                version_index := version_index + 1;
                        end loop;
                        split_count := split_count + 1;
		else 
			-- just set app_version to versions
			update tnt_config.desktop_app set app_version = versions where id = app_details.id;
                end if;
        end loop;

        return split_count;
end
'
 Language 'plpgsql'
 Volatile
 Called On Null Input
 Security invoker;

select tnt_config.desktop_app_split_versions();

-- 2 - merge instances of the same app with different processes into one row
create or replace function tnt_config.desktop_app_merge_processes()
returns int as
'
declare
        app_details record;
	merge_details record;
	stat_tablename text;
	parent_id int;
	all_ids int[];
	process_names text;
        merge_count int;
	update_id int;
begin
        merge_count := 0;

        FOR app_details in select name, app_version, count(*) from tnt_config.desktop_app group by name, app_version having count(*) > 1 LOOP
                raise warning ''App %, version % has more than one associated process'', app_details.name, app_details.app_version;
		parent_id := -1;
		all_ids := NULL;
		process_names := ''''; 
		for merge_details in select id, process_name from tnt_config.desktop_app where name = app_details.name and app_version = app_details.app_version loop
			raise warning ''Merging process %, id %'', merge_details.process_name, merge_details.id;
			if (process_names = '''') then
				process_names := merge_details.process_name;
			else
				process_names := process_names || '','' || merge_details.process_name;
			end if;
			if ((parent_id = -1) or (merge_details.id < parent_id)) then 
				parent_id := merge_details.id;
			end if;	
			if (all_ids = NULL) then
				all_ids = ARRAY[merge_details.id];
			else
				all_ids = array_append(all_ids, merge_details.id);
			end if;
		end loop;
		raise warning ''Processes %, ids: %, parent ID for merge is %'', process_names, all_ids, parent_id;
		for update_id in select tnt_audit.unnest(all_ids) loop
			if (update_id = parent_id) then
				raise warning ''Updating parent row with process list: %'', process_names;
				update tnt_config.desktop_app set process_name = process_names where id = update_id;
			else
				raise warning ''Redirecting statistics data associated with app % to %'', update_id, parent_id;
				for stat_tablename in select tablename from pg_tables where schemaname = ''tnt_audit'' and tablename like ''summaryreport_process_stats_%'' loop
					raise warning ''Updating %'', stat_tablename;
					execute ''update tnt_audit.'' || stat_tablename || '' set desk_app_id = '' || parent_id || '' where desk_app_id = '' || update_id;
					-- now delete this one 
					delete from tnt_config.desktop_app where id = update_id;
				end loop;
			end if;
			merge_count := merge_count + 1;
		end loop;
        end loop;

        return merge_count;
end
'
 Language 'plpgsql'
 Volatile
 Called On Null Input
 Security invoker;

select tnt_config.desktop_app_merge_processes();

-- take everything in process_name and move to process_names
update tnt_config.desktop_app set process_names = process_name;

-- drop function 
drop function tnt_config.desktop_app_split_versions();
drop function tnt_config.desktop_app_merge_processes();

-- setup constraints
alter table tnt_config.desktop_app alter column app_version set not null;

-- create new index
Create unique index "name_version_type_idx" on "tnt_config"."desktop_app" using btree ("name","type","app_version");

-- update view
create or replace view lwl_query.desktop_app_performance as
select
        
app.name as app_name,
app.app_version as app_version,
pstats.name as process_name,

pmachine.name as machine_name,
machinegroup.name as machine_group,

pstats.owner_name as user_name,
usergroup.name as user_group,

pstats.start_date as inspect_start_time_utc,
pstats.end_date as inspect_end_time_utc,

avg(pstats.launch_delay_ms)/1000 as launch_delay_s,
avg(case when pstats.non_responsive then 1 else 0 end) as num_non_responsive,
 
avg(pstats.cpu_avg_sys) as avg_system_cpu_percent,
avg(pstats.cpu_avg_user) as avg_user_cpu_percent,
avg(pstats.mem_avg / 1048576) as avg_mem_used_mb,
avg(pstats.pf_avg) as avg_page_faults,
avg(pstats.io_avg) as avg_io,
avg(pstats.graph_avg) as avg_graphics_intensity,

avg(pstats.cpu_peak_sys) as peak_system_cpu_percent,
avg(pstats.cpu_peak_user) as peak_user_cpu_percent,
avg(pstats.mem_peak / 1048576) as peak_mem_used_mb,
avg(pstats.pf_peak) as peak_page_faults,
avg(pstats.io_peak) as peak_io,
avg(pstats.graph_peak) as peak_graphics_intensity

from tnt_audit.summaryreport_process_stats pstats
join tnt_config.desktop_app app on (pstats.desk_app_id = app.id)

join tnt_config.policynode pmachine on (pstats.node_id = pmachine.id)

left outer join tnt_config.nodegroup_node ngroup on (
        (pstats.node_id = ngroup.nodeid)
        )

left outer join tnt_config.policynode machinegroup on (
        (ngroup.nodegroupid = machinegroup.id)
        )

left outer join tnt_config.identitygroup_identity igroup on (
        (pstats.owner_id = igroup.uid)
        )

left outer join tnt_config.policyidentity usergroup on (
        (igroup.groupid = usergroup.id)
        )

group by app_name, app_version, pstats.name, machine_name, machine_group, user_name, user_group, inspect_start_time_utc, inspect_end_time_utc
;

-- drop old columns
alter table tnt_config.desktop_app drop column process_name;
alter table tnt_config.desktop_app drop column versions; 

-- drop old columns
alter table tnt_config.desktop_app drop column process_name;
alter table tnt_config.desktop_app drop column versions;

Create table "tnt_config"."node_application"
(
        "desktop_app_id" Integer NOT NULL,
        "node_id" Integer NOT NULL,
        "install_date" Timestamp NOT NULL,
        "size" Integer NOT NULL,
        "svc_provided" Smallint,
        "svc_required" Smallint,
        "drv_provided" Smallint,
 primary key ("desktop_app_id","node_id")
) Without Oids;

Alter table "tnt_config"."node_application" add  foreign key ("node_id") references "tnt_config"."node" ("id") on update restrict on delete restrict;
Alter table "tnt_config"."node_application" add  foreign key ("desktop_app_id") references "tnt_config"."desktop_app" ("id") on update restrict on delete restrict;

Grant select on "tnt_config"."node_application" to "impadmin";
Grant update on "tnt_config"."node_application" to "impadmin";
Grant delete on "tnt_config"."node_application" to "impadmin";
Grant insert on "tnt_config"."node_application" to "impadmin";
Grant references on "tnt_config"."node_application" to "impadmin";
Grant select on "tnt_config"."node_application" to "reports";

alter table tnt_config.desktop_app add "parent_app_id" Integer;
alter table tnt_config.desktop_app add "is_patch" Boolean NOT NULL Default false;

Alter table "tnt_config"."desktop_app" add  foreign key ("parent_app_id") references "tnt_config"."desktop_app" ("id") on update restrict on delete restrict;
